@charset "UTF-8";
:root {
  interpolate-size: allow-keywords;
  --header-height: 27.6rem;
  --header-height-sp: 5.2rem;
}

/* Box sizing rules */
*,
*::before,
*::after {
  box-sizing: border-box;
}

/* Remove default margin */
body,
h1,
h2,
h3,
h4,
p,
figure,
blockquote,
dl,
dd {
  margin: 0;
}

/* Remove list styles on ul, ol elements with a list role, which suggests default styling will be removed */
ul[role=list],
ol[role=list] {
  list-style: none;
}

/* Set core root defaults */
html:focus-within {
  scroll-behavior: smooth;
}

/* Set core body defaults */
body {
  min-height: 100vh;
  text-rendering: optimizeSpeed;
  line-height: 1.5;
}

/* A elements that don't have a class get default styles */
a:not([class]) {
  -webkit-text-decoration-skip: ink;
          text-decoration-skip-ink: auto;
}

/* Make images easier to work with */
img,
picture {
  max-width: 100%;
  display: block;
}

/* Inherit fonts for inputs and buttons */
input,
button,
textarea,
select {
  font: inherit;
}

/*pagenavi*/

.wp-pagenavi {
clear: both;
text-align:center;

}
.wp-pagenavi a, .wp-pagenavi span {
display: inline-block;
color: #fff;
background-color: #80c9c3;
border: 1px solid #80c9c3;
padding: 8px 15px;
margin: 0 7px 7px 0;
white-space: nowrap;
-moz-border-radius: 3px;
-webkit-border-radius: 3px;
border-radius: 3px;
-webkit-transition: 0.2s ease-in-out;
-moz-transition: 0.2s ease-in-out;
-o-transition: 0.2s ease-in-out;
transition: 0.2s ease-in-out;
text-align: center;
text-decoration: none;
}
.wp-pagenavi a:hover{
color: #FFF;
background-color: #80c9c360;
border-color: #80c9c360;
}
.wp-pagenavi span.current{
display: inline-block;
color: #FFF;
background-color: #289bc0;
border-color: #289bc0;
font-weight: bold;
}

.article-navi{
text-align:center;
margin-top:8rem;
}


/* Remove all animations and transitions for people that prefer not to see them */
@media (prefers-reduced-motion: reduce) {
  html:focus-within {
    scroll-behavior: auto;
  }
  *,
  *::before,
  *::after {
    animation-duration: 0.01ms !important;
    animation-iteration-count: 1 !important;
    transition-duration: 0.01ms !important;
    scroll-behavior: auto !important;
  }
}
html {
  font-size: 0.6613756614dvw;
  scroll-padding-top: var(--header-height);
  scroll-behavior: smooth;
}
@media all and (max-width: 900px) {
  html {
    font-size: 3.125dvw;
    scroll-padding-top: var(--header-height-sp);
  }
}
@media screen and (min-width: 1512px) {
  html {
    font-size: 10px;
  }
}
@media screen and (max-width: 320px) {
  html {
    font-size: 10px;
  }
}
@media all and (max-width: 900px) {
  html.is-lock {
    scroll-behavior: auto;
  }
}

body {
  color: #555555;
  background-color: #ffffff;
  font-family: "Noto Sans JP", sans-serif;
  font-size: 1.8rem;
  font-optical-sizing: auto;
  -webkit-font-smoothing: antialiased;
  font-weight: 500;
  line-height: 1.7;
  margin: 0;
  padding: 0;
  overflow-y: scroll;
  overflow-wrap: anywhere;
}
@media all and (max-width: 900px) {
  body {
    font-size: 1.2rem;
    line-height: 1.6;
  }
}

p,
ul,
ol,
dl {
  margin: 0 0 2em;
  padding: 0;
}

a {
  color: #289bc0;
  text-decoration: underline;
  transition-duration: 0.3s;
}
a:hover {
  opacity: 0.8;
  text-decoration: none;
}

img,
svg {
  vertical-align: bottom;
}

input,
textarea,
select {
  font-family: inherit;
}

@media all and (max-width: 900px) {
  .pc-br {
    display: none;
  }
}

.sp-br {
  display: none;
}
@media all and (max-width: 900px) {
  .sp-br {
    display: inline;
  }
}

.wrap {
  display: grid;
  grid-template-rows: auto 1fr auto;
  width: 100%;
  min-width: 320px;
  min-height: 100dvh;
  overflow: clip;
  max-width: 1920px;
  margin-left: auto;
  margin-right: auto;
  box-shadow: 0 0 10rem rgba(0, 0, 0, 0.2);
}
@media all and (max-width: 900px) {
  .wrap.is-lock {
    position: fixed;
  }
}

.content {
  overflow: hidden;
}
.content__inner {
  padding: 12.8rem 0 16rem;
  background-color: #fffdee;
}
.blog__inner {
  padding: 7.8rem 0 16rem !important;
  background-color: #fffdee;
}
@media all and (max-width: 900px) {
  .content__inner {
    padding: 6.4rem 0 4.8rem;
  }
.blog__inner {
padding: 5rem 0 1rem !important;
margin: 0rem 0 1rem !important;
}
}

.container {
  max-width: 140rem;
  margin-right: auto;
  margin-left: auto;
}
@media all and (max-width: 900px) {
  .container {
    max-width: none;
    padding-left: 2rem;
    padding-right: 2rem;
  }
}
.has-side .container {
  display: flex;
  gap: 6rem;
  align-items: flex-start;
}
@media all and (max-width: 900px) {
  .has-side .container {
    flex-direction: column;
    gap: 4rem;
    }
}

.header {
  position: sticky;
  top: 0;
  left: 0;
  right: 0;
  height: var(--header-height);
  z-index: 8;
  background-color: #ffffff;
  border-top: 1.6rem solid #80c9c3;
  transition: top 0.3s;
}
@media all and (max-width: 900px) {
  .header {
    height: var(--header-height-sp);
    border-top-width: 0.5rem;
  }
}
.header.is-hidden {
  top: calc(var(--header-height) * -2);
}
@media all and (max-width: 900px) {
  .header.is-hidden {
    top: calc(var(--header-height-sp) * -2);
  }
}
.header.is-scrolled {
  box-shadow: 0 0 1rem rgba(0, 0, 0, 0.15);
}
.header__top {
  display: flex;
  height: 10.9rem;
  margin-bottom: 3.1rem;
}
.header__logo {
  padding: 1.7rem 0 0 0.3rem;
  flex: 0 0 37.8rem;
}
@media all and (max-width: 900px) {
  .header__logo {
    padding: 0.6rem 0 0 0;
    margin-left: -1.4rem;
    flex: 0 0 14.8rem;
  }
}
.header__logo img {
  width: 100%;
  height: auto;
}
.header__nav {
  display: flex;
  width: 43rem;
  height: 100%;
  border-radius: 0 0 1rem 1rem;
  overflow: hidden;
  margin: 0 0 0 auto;
}
@media all and (max-width: 900px) {
  .header__nav {
    display: none;
  }
}
.header__nav__item {
  flex: 1;
  margin: 0;
  padding: 0;
  list-style-type: none;
  height: 100%;
}
.header__nav__item a {
  position: relative;
  height: 100%;
  display: flex;
  justify-content: center;
  text-decoration: none;
  color: #fff;
  font-size: 1.9rem;
  font-weight: 700;
  padding-top: 6rem;
  background: #80c9c3 no-repeat 50% 1.6rem;
}
.header__nav__item a::before {
  content: "";
  position: absolute;
  top: 1.6rem;
  bottom: 2.3rem;
  left: -0.2rem;
  width: 0.4rem;
  background: radial-gradient(circle, #fff 0.2rem, transparent 0.2rem) repeat-y;
  background-size: 0.4rem 0.8rem;
  pointer-events: none;
}
.header__nav__item:first-child a::before {
  display: none;
}
.header__nav__item--blog a {
  background-image: url(../images/ic_blog_001.png);
  background-size: 3.3rem 3.3rem;
}
.header__nav__item--recruit a {
  background-image: url(../images/ic_recruit_001.png);
  background-size: 3.2rem 3.2rem;
}
.header__nav__item--access a {
  background-image: url(../images/ic_access_001.png);
  background-size: 2.8rem 3.2rem;
}
.header__global {
  position: relative;
  height: 12.1rem;
}
@media all and (max-width: 900px) {
  .header__global {
    display: none;
  }
}
.header__global__content {
  position: absolute;
  top: 12rem;
  left: 0;
  right: 0;
  margin: 0;
  padding: 0;
  max-height: calc(100vh - var(--header-height));
  display: none;
  height: 0;
  overflow: hidden;
  transition: all 0.3s;
}
.header__global__nav__item:hover .header__global__content {
  display: flex;
  height: auto;
  opacity: 1;
  overflow: visible;
}
@starting-style {
  .header__global__nav__item:hover .header__global__content {
    height: 0;
    opacity: 0;
  }
}
.is-hidden .header__global__content {
  display: none !important;
}
.header__global__content__col {
  position: relative;
  width: 42.5rem;
}
.header__global__content__col::before {
  content: "";
  position: absolute;
  top: 0;
  left: -100vw;
  right: 0;
  bottom: 0;
  background-color: #80c9c3;
  z-index: 1;
}
.header__global__content__col__inner {
  position: relative;
  display: flex;
  justify-content: flex-end;
  width: 100%;
  height: 100%;
  z-index: 2;
  padding: 4.8rem 6.4rem 4.8rem 0;
  color: #fff;
  font-size: 2.8rem;
  font-weight: 700;
}
.header__global__content__col__inner a {
  color: #fff;
  text-decoration: none;
}
.header__global__content__col2 {
  position: relative;
  flex: 1;
  padding: 1.2rem 0 0;
}
.header__global__content__col2::before {
  content: "";
  position: absolute;
  top: 0;
  left: 0;
  right: -100vw;
  bottom: 0;
  background-color: #f3faf9;
  z-index: 1;
}
.header__global__content__col2__inner {
  position: relative;
  display: flex;
  width: 100%;
  height: 100%;
  z-index: 2;
  padding: 3.6rem 3.2rem 4.8rem 6.4rem;
  overflow-y: auto;
}
.header__global__nav {
  display: flex;
  list-style-type: none;
  margin: 0;
  height: 100%;
}
.header__global__nav__item > a {
  position: relative;
  background: no-repeat 50% 0;
  display: flex;
  justify-content: center;
  align-items: end;
  height: 8.6rem;
  color: #555555;
  font-size: 1.8rem;
  font-weight: 700;
  text-decoration: none;
}
.header__global__nav__item > a::before {
  content: "";
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  width: 0.4rem;
  background: radial-gradient(circle, #bbbbbb 0.2rem, transparent 0.2rem) repeat-y;
  background-size: 0.4rem 0.8rem;
  pointer-events: none;
}
.header__global__nav__item > a::after {
  content: "";
  display: none;
  position: absolute;
  top: 0;
  bottom: 0;
  right: 0;
  width: 0.4rem;
  background: radial-gradient(circle, #bbbbbb 0.2rem, transparent 0.2rem) repeat-y;
  background-size: 0.4rem 0.8rem;
  pointer-events: none;
}
.header__global__nav__item:last-child > a::after {
  display: block;
}
.header__global__nav__item--about {
  width: 23.2rem;
}
.header__global__nav__item--about > a {
  background-image: url(../images/ic_about_001.png);
  background-size: 4.6rem 4.8rem;
}
.header__global__nav__item--feature {
  width: 21.2rem;
}
.header__global__nav__item--feature > a {
  background-image: url(../images/ic_feature_001.png);
  background-size: 5.2rem 4rem;
}
.header__global__nav__item--life {
  width: 21.2rem;
}
.header__global__nav__item--life > a {
  background-image: url(../images/ic_life_001.png);
  background-size: 5.7rem 4.1rem;
}
.header__global__nav__item--admission {
  width: 31.4rem;
}
.header__global__nav__item--admission > a {
  background-image: url(../images/ic_admission_001.png);
  background-size: 5.9rem 4.1rem;
}
.header__global__nav__item--news {
  width: 21.2rem;
}
.header__global__nav__item--news > a {
  background-image: url(../images/ic_news_001.png);
  background-size: 3.9rem 4.1rem;
}
.header__global__nav__item--contact {
  width: 21.8rem;
}
.header__global__nav__item--contact > a {
  background-image: url(../images/ic_contact_001.png);
  background-size: 5.4rem 4rem;
}
.header__global__nav2 {
  display: flex;
  flex-wrap: wrap;
  gap: 2rem 2.8rem;
  list-style-type: none;
  margin: 0;
}
.header__global__nav2__item {
  width: 38rem;
}
.header__global__nav2__item__inner {
  position: relative;
  display: flex;
  width: 100%;
  height: 100%;
  padding: 0 3.6rem;
  justify-content: center;
  align-items: center;
  z-index: 3;
}
.header__global__nav2__item__inner::after {
  content: "";
  position: absolute;
  top: 0;
  right: 3.4rem;
  bottom: 0;
  margin: auto 0;
  width: 1rem;
  height: 2rem;
  background-color: #45ada4;
  clip-path: polygon(0% 0%, 100% 50%, 0% 100%);
}
.header__global__nav2__item > a {
  position: relative;
  width: 100%;
  height: 4.8rem;
  display: flex;
  font-size: 1.8rem;
  font-weight: 700;
  color: #45ada4;
  text-decoration: none;
}
.header__global__nav2__item > a::after {
  content: "";
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  border-radius: 3.2rem;
  border: 0.2rem solid #45ada4;
  background-color: #fff;
  z-index: 2;
}
.header__global__nav2__item > a::before {
  content: "";
  position: absolute;
  right: -0.6rem;
  bottom: -0.6rem;
  width: 100%;
  height: 100%;
  border-radius: 4rem;
  background-color: #bee2de;
  z-index: 1;
}
.header__global__nav3 {
  display: flex;
  flex-direction: column;
  gap: 1.8rem 2rem;
  margin: 1.8rem 0 0;
  list-style-type: none;
}
.header__global__nav3__item {
  width: 34rem;
  margin: 0 auto;
}
.header__global__nav3__item__inner {
  position: relative;
  display: flex;
  width: 100%;
  height: 100%;
  padding: 0 2.8rem;
  justify-content: center;
  align-items: center;
  z-index: 3;
}
.header__global__nav3__item__inner::after {
  content: "";
  position: absolute;
  top: 0;
  right: 3.4rem;
  bottom: 0;
  margin: auto 0;
  width: 1rem;
  height: 2rem;
  background-color: #fff;
  clip-path: polygon(0% 0%, 100% 50%, 0% 100%);
}
.header__global__nav3__item > a {
  position: relative;
  width: 100%;
  height: 4.2rem;
  display: flex;
  font-size: 1.8rem;
  font-weight: 700;
  color: #fff;
  text-decoration: none;
}
.header__global__nav3__item > a::after {
  content: "";
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  border-radius: 2.8rem;
  background-color: #80c9c3;
  z-index: 2;
}
.header__global__nav3__item > a::before {
  content: "";
  position: absolute;
  right: -0.6rem;
  bottom: -0.6rem;
  width: 100%;
  height: 100%;
  border-radius: 3.2rem;
  background-color: #bee2de;
  z-index: 1;
}
.header__global__nav4 {
  display: flex;
  flex-direction: column;
  gap: 0;
  margin: 1rem 2.2rem 0;
  list-style-type: none;
}
.header__global__nav4__item {
  margin: 0;
  border-bottom: 0.2rem dotted #45ada4;
}
.header__global__nav4__item > a {
  position: relative;
  width: 100%;
  display: flex;
  justify-content: center;
  font-size: 1.7rem;
  font-weight: 700;
  color: #45ada4;
  text-decoration: none;
  padding: 1rem 3.2rem;
}
.header__global__nav4__item > a::after {
  content: "";
  position: absolute;
  top: 0;
  right: 1.6rem;
  bottom: 0;
  margin: auto 0;
  width: 1rem;
  height: 2rem;
  background-color: #45ada4;
  clip-path: polygon(0% 0%, 100% 50%, 0% 100%);
}
.header__hamburger {
  display: none;
}
@media all and (max-width: 900px) {
  .header__hamburger {
    display: block;
    position: absolute;
    top: 0;
    right: 0;
    width: 5rem;
    height: 4.7rem;
  }
}
.header__hamburger a {
  position: relative;
  display: block;
  width: 100%;
  height: 100%;
}
.header__hamburger a span {
  display: block;
  width: 100%;
  height: 100%;
  text-indent: -9999rem;
}
.header__hamburger a::before, .header__hamburger a::after,
.header__hamburger a span::before {
  content: "";
  position: absolute;
  left: 0;
  right: 0;
  margin: 0 auto;
  width: 2rem;
  height: 0.2rem;
  background-color: #2369b2;
  transition: 0.3s;
}
.header__hamburger a::before {
  top: 1.7rem;
}
.header__hamburger a::after {
  bottom: 1.7rem;
}
.header__hamburger a span::before {
  top: 50%;
  margin-top: -0.1rem;
}
.header__hamburger a.is-open::before {
  top: 1.95rem;
  transform: rotate(-45deg);
}
.header__hamburger a.is-open::after {
  bottom: 2.1em;
  transform: rotate(45deg);
}
.header__hamburger a.is-open span::before {
  opacity: 0;
}

.footer {
  padding: 10rem 0 5.6rem;
  background-color: #80c9c3;
}
@media all and (max-width: 900px) {
  .footer {
    padding: 4.8rem 0 6rem;
  }
}
.footer__sns {
  display: flex;
  gap: 4rem;
}
@media all and (max-width: 900px) {
  .footer__sns {
    flex-direction: column;
    gap: 2rem;
  }
}
.footer__line {
  display: flex;
  gap: 1.2rem;
  align-items: center;
  flex: 1;
  padding: 2rem;
  background-color: #fff;
  border-radius: 1.2rem;
}
@media all and (max-width: 900px) {
  .footer__line {
    padding: 0.8rem;
    border-radius: 0.8rem;
    box-shadow: 0 0 0.4rem rgba(0, 0, 0, 0.15);
  }
}
.footer__line__col {
  flex: 1;
}
.footer__line__col2 {
  width: 16.6rem;
}
@media all and (max-width: 900px) {
  .footer__line__col2 {
    display: none;
  }
}
.footer__line__col2 img {
  width: 100%;
  height: auto;
}
.footer__line__txt {
  font-size: 1.9rem;
  font-weight: 700;
  text-align: center;
  color: #00a242;
  margin: 0 0 1.6rem;
}
@media all and (max-width: 900px) {
  .footer__line__txt {
    font-size: 1.1rem;
    margin-bottom: 1rem;
  }
}
.footer__line__btn {
  display: flex;
  align-items: center;
  justify-content: center;
  height: 11rem;
  clip-path: polygon(0% 0%, calc(100% - 3.2rem) 0%, 100% 50%, calc(100% - 3.2rem) 100%, 0% 100%);
  background-color: #06c755;
  color: #fff;
  text-decoration: none;
  font-size: 2.8rem;
  font-weight: 700;
}
@media all and (max-width: 900px) {
  .footer__line__btn {
    position: relative;
    height: 3.5rem;
    clip-path: none;
    font-size: 1.3rem;
    border-radius: 0.4rem;
  }
}
.footer__line__btn::after {
  display: none;
  content: "";
  position: absolute;
  top: 0;
  bottom: 0;
  right: 1.2rem;
  width: 0.8rem;
  height: 1.4rem;
  margin: auto 0;
  clip-path: polygon(0% 0%, 100% 50%, 0% 100%);
  background-color: #fff;
}
@media all and (max-width: 900px) {
  .footer__line__btn::after {
    display: block;
  }
}
.footer__line__btn__inner {
  display: inline-block;
  position: relative;
  padding-left: 9.2rem;
}
@media all and (max-width: 900px) {
  .footer__line__btn__inner {
    padding-left: 4rem;
  }
}
.footer__line__btn__inner::before {
  content: "";
  position: absolute;
  top: 50%;
  left: 0;
  transform: translateY(-48%);
  width: 9rem;
  height: 9rem;
  background: url(../images/ic_line_001.png) no-repeat 0 0;
  background-size: 100% 100%;
}
@media all and (max-width: 900px) {
  .footer__line__btn__inner::before {
    width: 3rem;
    height: 3rem;
  }
}
.footer__instagram {
  display: flex;
  gap: 1.2rem;
  align-items: center;
  flex: 1;
  padding: 2rem;
  background-color: #fff;
  border-radius: 1.2rem;
}
@media all and (max-width: 900px) {
  .footer__instagram {
    padding: 0.8rem;
    border-radius: 0.8rem;
    box-shadow: 0 0 0.4rem rgba(0, 0, 0, 0.15);
  }
}
.footer__instagram__col {
  flex: 1;
}
.footer__instagram__col2 {
  width: 16.6rem;
}
@media all and (max-width: 900px) {
  .footer__instagram__col2 {
    display: none;
  }
}
.footer__instagram__col2 img {
  width: 100%;
  height: auto;
}
.footer__instagram__txt {
  font-size: 1.9rem;
  font-weight: 700;
  text-align: center;
  color: #fd1068;
  margin: 0 0 1.6rem;
}
@media all and (max-width: 900px) {
  .footer__instagram__txt {
    font-size: 1.1rem;
    margin-bottom: 1rem;
  }
}
.footer__instagram__btn {
  position: relative;
  display: flex;
  align-items: center;
  justify-content: center;
  height: 11rem;
  clip-path: polygon(0% 0%, calc(100% - 3.2rem) 0%, 100% 50%, calc(100% - 3.2rem) 100%, 0% 100%);
  background: linear-gradient(151deg, #8015FE 0%, #ED00BE 37%, #FE2B57 64%, #FFB205 100%);
  color: #fff;
  text-decoration: none;
  font-size: 2.8rem;
  font-weight: 700;
}
@media all and (max-width: 900px) {
  .footer__instagram__btn {
    position: relative;
    height: 3.5rem;
    clip-path: none;
    font-size: 1.3rem;
    border-radius: 0.4rem;
  }
}
.footer__instagram__btn::after {
  display: none;
  content: "";
  position: absolute;
  top: 0;
  bottom: 0;
  right: 1.2rem;
  width: 0.8rem;
  height: 1.4rem;
  margin: auto 0;
  clip-path: polygon(0% 0%, 100% 50%, 0% 100%);
  background-color: #fff;
}
@media all and (max-width: 900px) {
  .footer__instagram__btn::after {
    display: block;
  }
}
.footer__instagram__btn__inner {
  display: inline-block;
}
@media all and (max-width: 900px) {
  .footer__instagram__btn__inner {
    position: relative;
    padding-left: 3.2rem;
  }
}
.footer__instagram__btn__inner::before {
  content: "";
  position: absolute;
  top: 50%;
  left: 2.2rem;
  transform: translateY(-50%);
  width: 6.4rem;
  height: 6.4rem;
  background: url(../images/ic_instagram_001.png) no-repeat 0 0;
  background-size: 100% 100%;
}
@media all and (max-width: 900px) {
  .footer__instagram__btn__inner::before {
    left: 0;
    width: 2rem;
    height: 2rem;
  }
}
.footer__btns {
  display: flex;
  gap: 4rem;
  margin: 4rem 0 0;
  list-style-type: none;
}
@media all and (max-width: 900px) {
  .footer__btns {
    flex-direction: column;
    gap: 2rem;
    margin-top: 2rem;
  }
}
.footer__btns > li {
  flex: 1;
}
.footer__btn {
  position: relative;
  display: flex;
  align-items: center;
  justify-content: center;
  background-color: #fff;
  border-radius: 1.2rem;
  height: 11.2rem;
  color: #4aa9a1;
  font-size: 2.8rem;
  font-weight: 700;
  text-decoration: none;
}
@media all and (max-width: 900px) {
  .footer__btn {
    border-radius: 0.8rem;
    height: 5.2rem;
    font-size: 1.3rem;
    box-shadow: 0 0 0.4rem rgba(0, 0, 0, 0.15);
  }
}
.footer__btn::before {
  content: "";
  position: absolute;
  top: 0;
  bottom: 0;
  right: 2.2rem;
  width: 1.6rem;
  height: 2.9rem;
  margin: auto 0;
  clip-path: polygon(0% 0%, 100% 50%, 0% 100%);
  background-color: #4aa9a1;
}
@media all and (max-width: 900px) {
  .footer__btn::before {
    right: 1.2rem;
    width: 0.8rem;
    height: 1.4rem;
  }
}
.footer__btn__inner {
  position: relative;
  display: inline-block;
  padding-left: 6.8rem;
}
@media all and (max-width: 900px) {
  .footer__btn__inner {
    padding-left: 2.8rem;
    margin-left: -2.2rem;
  }
}
.footer__btn__inner::before {
  content: "";
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  margin: auto 0;
  background: no-repeat 0 0;
  background-size: 100% 100%;
}
.footer__btn--blog .footer__btn__inner::before {
  width: 3.8rem;
  height: 3.8rem;
  background-image: url(../images/ic_blog_002.png);
}
@media all and (max-width: 900px) {
  .footer__btn--blog .footer__btn__inner::before {
    width: 1.8rem;
    height: 1.8rem;
  }
}
.footer__btn--news .footer__btn__inner::before {
  width: 3.9rem;
  height: 4.1rem;
  background-image: url(../images/ic_news_002.png);
}
@media all and (max-width: 900px) {
  .footer__btn--news .footer__btn__inner::before {
    width: 1.6rem;
    height: 1.7rem;
  }
}
.footer__navs {
  display: flex;
  flex-wrap: wrap;
  gap: 7.8rem;
  margin-top: 10rem;
}
@media all and (max-width: 900px) {
  .footer__navs {
    gap: 2rem 1.8rem;
    margin-top: 4rem;
  }
}
.footer__navs a {
  text-decoration: none;
  color: #fff;
}
.footer__nav {
  width: 28.9rem;
  margin: 0;
}
@media all and (max-width: 900px) {
  .footer__nav {
    width: calc(50% - 0.9rem);
  }
}
.footer__nav > dt {
  padding: 1.2rem;
  font-size: 2rem;
  font-weight: 700;
  border-top: 0.2rem dotted #fff;
  border-bottom: 0.2rem dotted #fff;
}
@media all and (max-width: 900px) {
  .footer__nav > dt {
    padding: 0.6rem 0.5rem;
    border-top: 1px solid #fff;
    border-bottom: 1px solid #fff;
    font-size: 1.2rem;
  }
}
.footer__nav > dt a {
  display: block;
  margin: -1.2rem;
  padding: 1.2rem;
}
@media all and (max-width: 900px) {
  .footer__nav > dt a {
    margin: -0.6rem -0.5rem;
    padding: 0.6rem 0.5rem;
  }
}
.footer__nav > dd {
  padding: 2.4rem 1.2rem 0;
}
@media all and (max-width: 900px) {
  .footer__nav > dd {
    padding: 0.8rem 0.5rem 0;
  }
}
.footer__nav2 {
  display: flex;
  flex-direction: column;
  gap: 1rem;
  margin: 0;
  list-style-type: none;
}
@media all and (max-width: 900px) {
  .footer__nav2 {
    gap: 0.6rem;
    font-size: 1.1rem;
  }
}
.footer__nav2 a {
  display: block;
}
.footer__nav3 {
  display: flex;
  flex-direction: column;
  gap: 0.8rem;
  margin: 1rem 0 0;
  list-style-type: none;
}
@media all and (max-width: 900px) {
  .footer__nav3 {
    gap: 0.4rem;
    margin: 0.6rem 0 0;
    font-size: 1rem;
  }
}
.footer__nav3 a {
  position: relative;
  display: block;
  position: relative;
  padding-left: 1rem;
}
@media all and (max-width: 900px) {
  .footer__nav3 a {
    padding-left: 0.6rem;
  }
}
.footer__nav3 a::before {
  content: "";
  position: absolute;
  top: 0.8em;
  left: 0;
  width: 0.5rem;
  height: 0.2rem;
  background-color: #fff;
}
@media all and (max-width: 900px) {
  .footer__nav3 a::before {
    width: 0.3rem;
    height: 1px;
  }
}
.footer__logo {
  margin: 10rem auto 0;
  width: 38rem;
}
@media all and (max-width: 900px) {
  .footer__logo {
    margin-top: 4rem;
    width: 18rem;
  }
}
.footer__logo img {
  width: 100%;
  height: auto;
}
.footer__address {
  margin: 4.8rem 0 0;
  text-align: center;
  color: #fff;
  font-size: 1.4rem;
  line-height: 1.8;
}
@media all and (max-width: 900px) {
  .footer__address {
    margin-top: 2.4rem;
    font-size: 1rem;
  }
}
.footer__copyright {
  margin: 5.6rem 0 0;
  text-align: center;
  color: #fff;
  font-size: 1.4rem;
}
@media all and (max-width: 900px) {
  .footer__copyright {
    margin-top: 2rem;
    font-size: 1rem;
  }
}

.pagetop {
  position: fixed;
  bottom: 2rem;
  right: 2rem;
  z-index: 10;
  width: 8rem;
  height: 8rem;
}
@media all and (max-width: 900px) {
  .pagetop {
    bottom: 5rem;
    right: 0.8rem;
    width: 3.6rem;
    height: 3.6rem;
  }
}
.pagetop a {
  position: relative;
  display: block;
  width: 100%;
  height: 100%;
  text-indent: -999rem;
  background-color: #80c9c3;
  border-radius: 1rem;
  box-shadow: 0 0 1.2rem rgba(0, 0, 0, 0.3);
}
@media all and (max-width: 900px) {
  .pagetop a {
    border-radius: 0.4rem;
    box-shadow: 0 0 0.4rem rgba(0, 0, 0, 0.3);
  }
}
.pagetop a::before, .pagetop a::after {
  content: "";
  position: absolute;
  top: 2.4rem;
  left: calc(50% - 0.2rem);
  width: 0.4rem;
  height: 3.2rem;
  background-color: #ffffff;
  transform-origin: 50% 0.2rem;
}
@media all and (max-width: 900px) {
  .pagetop a::before, .pagetop a::after {
    top: 1.2rem;
    left: calc(50% - 0.1rem);
    width: 0.2rem;
    height: 1.6rem;
    border-radius: 0.4rem;
  }
}
.pagetop a::before {
  transform: rotate(45deg);
}
.pagetop a::after {
  transform: rotate(-45deg);
}

.drawer {
  display: none;
  position: fixed;
  z-index: 110;
  top: var(--header-height-sp);
  width: 100dvw;
  right: -110dvw;
  bottom: 0;
  background-color: #80c9c3;
  padding: 3.2rem 1.8rem 0;
  overflow-y: auto;
  transition: 0.3s;
  font-family: var(--font-family-ja);
}
@media all and (max-width: 900px) {
  .drawer {
    display: block;
  }
}
.drawer.is-open {
  right: 0;
}
.drawer__inner {
  padding-bottom: 3.2rem;
}
.drawer__row {
  display: flex;
  gap: 1.8rem;
  margin-bottom: 3.6rem;
}
.drawer__col {
  display: flex;
  flex-direction: column;
  gap: 2.6rem;
  flex: 1;
}
.drawer__nav {
  margin: 0;
}
.drawer__nav a {
  text-decoration: none;
  color: #fff;
}
.drawer__nav > dt {
  padding: 0.6rem 0.5rem;
  border-top: 1px solid #fff;
  border-bottom: 1px solid #fff;
  font-size: 1.2rem;
}
.drawer__nav > dt > a {
  display: block;
  margin: -0.6rem -0.5rem;
  padding: 0.6rem 0.5rem;
}
.drawer__nav > dd {
  padding: 0.8rem 0.5rem 0;
}
.drawer__nav2 {
  display: flex;
  flex-direction: column;
  gap: 0.6rem;
  margin: 0;
  list-style-type: none;
  font-size: 1.1rem;
}
.drawer__nav2 > li > a {
  display: block;
}
.drawer__nav3 {
  display: flex;
  flex-direction: column;
  gap: 0.4rem;
  margin: 0.6rem 0 0;
  list-style-type: none;
  font-size: 1rem;
}
.drawer__nav3 > li > a {
  position: relative;
  display: block;
  padding-left: 0.6rem;
}
.drawer__nav3 > li > a::before {
  content: "";
  position: absolute;
  top: 0.8em;
  left: 0;
  width: 0.3rem;
  height: 1px;
  background-color: #fff;
}
.drawer__line {
  margin-top: 1.6rem;
}
.drawer__line__btn {
  display: block;
  padding: 1.4rem 0.8rem 0.8rem;
  background-color: #fff;
  border-radius: 0.6rem;
  box-shadow: 0 0 0.4rem rgba(0, 0, 0, 0.15);
  text-decoration: none;
}
.drawer__line__txt {
  font-size: 1.1rem;
  font-weight: 700;
  color: #00a242;
  text-align: center;
  margin: 0 0 1.2rem;
}
.drawer__line__txt2 {
  position: relative;
  display: flex;
  align-items: center;
  justify-content: center;
  height: 3.6rem;
  padding: 0.4rem 2.4rem;
  background-color: #12c760;
  border-radius: 0.4rem;
  margin: 0;
  color: #fff;
  font-size: 1.3rem;
  font-weight: 700;
}
.drawer__line__txt2::after {
  content: "";
  position: absolute;
  top: 0;
  right: 1.1rem;
  bottom: 0;
  margin: auto 0;
  width: 0.8rem;
  height: 1.5rem;
  background-color: #fff;
  clip-path: polygon(0% 0%, 100% 50%, 0% 100%);
}
.drawer__line__txt2__inner {
  position: relative;
  display: inline-block;
  padding-left: 3.6rem;
}
.drawer__line__txt2__inner::before {
  content: "";
  position: absolute;
  top: 50%;
  left: 0;
  transform: translateY(-50%);
  width: 3.2rem;
  height: 3.2rem;
  background: url(../images/ic_line_001.png) no-repeat 0 0;
  background-size: 100% 100%;
}
.drawer__instagram {
  margin-top: 1.6rem;
}
.drawer__instagram__btn {
  display: block;
  padding: 1.4rem 0.8rem 0.8rem;
  background-color: #fff;
  border-radius: 0.6rem;
  box-shadow: 0 0 0.4rem rgba(0, 0, 0, 0.15);
  text-decoration: none;
}
.drawer__instagram__txt {
  font-size: 1.1rem;
  font-weight: 700;
  color: #fd1068;
  text-align: center;
  margin: 0 0 1.2rem;
}
.drawer__instagram__txt2 {
  position: relative;
  display: flex;
  align-items: center;
  justify-content: center;
  height: 3.6rem;
  padding: 0.4rem 2.4rem;
  background: linear-gradient(151deg, #8015FE 0%, #ED00BE 37%, #FE2B57 64%, #FFB205 100%);
  border-radius: 0.4rem;
  margin: 0;
  color: #fff;
  font-size: 1.3rem;
  font-weight: 700;
}
.drawer__instagram__txt2::after {
  content: "";
  position: absolute;
  top: 0;
  right: 1.1rem;
  bottom: 0;
  margin: auto 0;
  width: 0.8rem;
  height: 1.5rem;
  background-color: #fff;
  clip-path: polygon(0% 0%, 100% 50%, 0% 100%);
}
.drawer__instagram__txt2__inner {
  position: relative;
  display: inline-block;
  padding-left: 3.4rem;
}
.drawer__instagram__txt2__inner::before {
  content: "";
  position: absolute;
  top: 50%;
  left: 0;
  transform: translateY(-50%);
  width: 2rem;
  height: 2rem;
  background: url(../images/ic_instagram_001.png) no-repeat 0 0;
  background-size: 100% 100%;
}
.drawer__btns {
  margin: 1.6rem 0 0;
  display: flex;
  flex-direction: column;
  gap: 1.6rem;
  list-style-type: none;
}
.drawer__btn {
  position: relative;
  display: flex;
  align-items: center;
  justify-content: center;
  height: 5.2rem;
  padding: 1.4rem 3.2rem;
  background-color: #fff;
  border-radius: 0.6rem;
  box-shadow: 0 0 0.4rem rgba(0, 0, 0, 0.15);
  text-decoration: none;
  font-size: 1.3rem;
  font-weight: 700;
  color: #4aa9a1;
}
.drawer__btn::after {
  content: "";
  position: absolute;
  top: 0;
  right: 1.1rem;
  bottom: 0;
  margin: auto 0;
  width: 0.8rem;
  height: 1.5rem;
  background-color: #45ada4;
  clip-path: polygon(0% 0%, 100% 50%, 0% 100%);
}
.drawer__btn__inner {
  position: relative;
  display: inline-block;
  padding-left: 2.8rem;
}
.drawer__btn__inner::before {
  content: "";
  position: absolute;
  left: 0;
  top: 50%;
  transform: translateY(-50%);
  background: no-repeat 0 0;
  background-size: 100% 100%;
}
.drawer__btn--blog .drawer__btn__inner::before {
  width: 1.8rem;
  height: 1.8rem;
  background-image: url(../images/ic_blog_002.png);
}
.drawer__btn--news .drawer__btn__inner::before {
  width: 1.6rem;
  height: 1.7rem;
  background-image: url(../images/ic_news_002.png);
}

.fixed-nav {
  position: fixed;
  z-index: 10;
  right: 0;
  top: 50%;
  transform: translateY(-30%);
}
@media all and (max-width: 900px) {
  .fixed-nav {
    top: auto;
    left: 0;
    bottom: 0;
    transform: none;
  }
}
.fixed-nav__list {
  display: flex;
  flex-direction: column;
  gap: 2rem;
  margin: 0;
  list-style-type: none;
}
@media all and (max-width: 900px) {
  .fixed-nav__list {
    flex-direction: row;
    gap: 0;
  }
}
@media all and (max-width: 900px) {
  .fixed-nav__list__item {
    flex: 1;
  }
}
.fixed-nav__list__item a {
  position: relative;
  display: flex;
  width: 5.5rem;
  padding: 2rem 1.2rem;
  font-size: 1.8rem;
  font-weight: 700;
  color: #fff;
  text-align: center;
  text-decoration: none;
  line-height: 1.4;
  background-color: #000;
  border-radius: 0.5rem 0 0 0.5rem;
  box-shadow: 0 0 1rem rgba(0, 0, 0, 0.2);
}
@media all and (max-width: 900px) {
  .fixed-nav__list__item a {
    align-items: center;
    justify-content: center;
    width: auto;
    height: 4rem;
    padding: 0;
    font-size: 1.1rem;
    border-radius: 0;
    box-shadow: none;
  }
}
.fixed-nav__list__item--admission a {
  background-color: #e25b6b;
}
.fixed-nav__list__item--contact a {
  background-color: #289bc0;
}
.fixed-nav__list__item__inner {
  position: relative;
  display: block;
  padding-top: 5rem;
}
@media all and (max-width: 900px) {
  .fixed-nav__list__item__inner {
    padding-top: 0;
    padding-left: 3.2rem;
  }
}
.fixed-nav__list__item__inner::before {
  content: "";
  position: absolute;
  top: 0;
  left: 50%;
  transform: translateX(-50%);
  width: 4rem;
  height: 4rem;
  background: no-repeat 0 0;
  background-size: 100% 100%;
}
@media all and (max-width: 900px) {
  .fixed-nav__list__item__inner::before {
    top: 50%;
    left: 0;
    transform: translateY(-50%);
    width: 2.4rem;
    height: 2.4rem;
  }
}
.fixed-nav__list__item--admission .fixed-nav__list__item__inner::before {
  background-image: url(../images/ic_admission_002.png);
}
.fixed-nav__list__item--contact .fixed-nav__list__item__inner::before {
  background-image: url(../images/ic_contact_002.png);
}
.breadcrumbs-wrap {
  position: relative;
  z-index: 2;
  height: 6.8rem;
  padding-top: 3.6rem;
  margin-bottom: -6.8rem;
}
@media all and (max-width: 900px) {
  .breadcrumbs-wrap {
    height: 3.2rem;
    padding-top: 1.2rem;
    margin-bottom: -3.2rem;
  }
}

.breadcrumbs {
  font-size: 1.8rem;
  color: #555555;
}
@media all and (max-width: 900px) {
  .breadcrumbs {
    font-size: 1.1rem;
  }
}
.breadcrumbs a {
  text-decoration: none;
}

.main {
  position: relative;
/*  padding: 4.8rem 6rem 16rem; */
    padding: 4.8rem 6rem 10rem;
  border-radius: 1.4rem;
  background-color: #fff;
  box-shadow: 0 0 0.8rem rgba(0, 0, 0, 0.15);
  overflow: hidden;
}
@media all and (max-width: 900px) {
  .main {
    padding: 2rem 1.6rem 4rem;
    border-radius: 0.7rem;
    box-shadow: 0 0 0.4rem rgba(0, 0, 0, 0.15);
  }
}
.main::before {
  content: "";
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  height: 0.4rem;
  background-color: #45ada4;
}
.has-side .main {
  order: 2;
  flex: 1;
}
@media all and (max-width: 900px) {
  .has-side .main {
    order: 1;
    width: 100%;
  }
}
.main > :last-child {
  margin-bottom: 0;
}

.side {
  position: relative;
}
.has-side .side {
  order: 1;
  width: 30rem;
}
@media all and (max-width: 900px) {
  .has-side .side {
    order: 2;
/*    width: auto; */
    width: 100%;
  }
}
.side__inner > :last-child {
  margin-bottom: 0;
}
.side__nav {
  border-radius: 1.4rem;
  box-shadow: 0 0 0.8rem rgba(0, 0, 0, 0.15);
  overflow: hidden;
}
@media all and (max-width: 900px) {
  .side__nav {
    border-radius: 0.7rem;
    box-shadow: 0 0 0.4rem rgba(0, 0, 0, 0.15);
  }
}
.side__nav__ttl {
  padding: 1.6rem 1.2rem;
  background-color: #45ada4;
  color: #fff;
  font-size: 2.2rem;
  font-weight: 700;
  text-align: center;
}
@media all and (max-width: 900px) {
  .side__nav__ttl {
    font-size: 1.5rem;
    padding: 0.8rem 1.2rem;
  }
}
.side__nav__ttl a {
  display: block;
  margin: -1.6rem -1.2rem;
  padding: 1.6rem 1.2rem;
  color: #fff;
  text-decoration: none;
}
@media all and (max-width: 900px) {
  .side__nav__ttl a {
    margin: -0.8rem -1.2rem;
    padding: 0.8rem 1.2rem;
  }
}
.side__nav2 {
  margin: 0;
  list-style-type: none;
  font-size: 1.8rem;
}
@media all and (max-width: 900px) {
  .side__nav2 {
    font-size: 1.2rem;
  }
}
.side__nav2__item {
  border-bottom: 0.2rem solid #e0e7f2;
}
.side__nav2__item:last-child {
  border-bottom: none;
}
.side__nav2__item a {
  position: relative;
  display: block;
  padding: 2rem 1.2rem;
  background-color: #fff;
  color: #45ada4;
  text-decoration: none;
}
@media all and (max-width: 900px) {
  .side__nav2__item a {
    padding: 1.2rem;
  }
}
.side__nav3 {
  margin: 0;
  list-style-type: none;
  font-size: 1.8rem;
}
@media all and (max-width: 900px) {
  .side__nav3 {
    font-size: 1.2rem;
  }
}
.side__nav3__item {
  border-bottom: 0.2rem solid #e0e7f2;
}
.side__nav3__item:last-child {
  border-bottom: none;
}
.side__nav3__item a {
  background-color: #edf9f7;
  padding-left: 2.2rem;
}
.side__nav3__item a::before {
  position: absolute;
  content: "-";
  top: 2rem;
  left: 1.2rem;
}
@media all and (max-width: 900px) {
  .side__nav3__item a::before {
    top: 1.1rem;
  }
}
.side__nav4 {
  margin: 0;
  list-style-type: none;
  font-size: 1.8rem;
}
@media all and (max-width: 900px) {
  .side__nav4 {
    font-size: 1.2rem;
  }
}
.side__nav4__item {
  border-bottom: 0.2rem solid #e0e7f2;
}
.side__nav4__item:last-child {
  border-bottom: none;
}
.side__nav4__item a {
  background-color: #d2efec;
  padding-left: 3.2rem;
}
.side__nav4__item a::before {
  position: absolute;
  content: "└";
  top: 2rem;
  left: 1.2rem;
}
@media all and (max-width: 900px) {
  .side__nav4__item a::before {
    top: 1.1rem;
  }
}
.side__bnr {
  display: flex;
  flex-direction: column;
  gap: 3rem;
  margin: 4rem 0 0;
  list-style-type: none;
}
@media all and (max-width: 900px) {
  .side__bnr {
    gap: 2rem;
    margin-top: 3rem;
  }
}
.side__bnr__item a {
  display: block;
  position: relative;
}
.side__bnr__txt {
  position: absolute;
  z-index: 2;
  left: 0;
  right: 0;
  display: flex;
  align-items: center;
  justify-content: center;
  height: 4rem;
  bottom: 1.2rem;
  background-color: #45ada4;
  color: #fff;
  font-size: 1.8rem;
  font-weight: 700;
  line-height: 1.2;
  clip-path: polygon(0% 0%, 100% 0%, calc(100% - 1.2rem) 50%, 100% 100%, 0% 100%, 1.2rem 50%);
}
@media all and (max-width: 900px) {
  .side__bnr__txt {
    height: 3.2rem;
    font-size: 1.2rem;
    clip-path: polygon(0% 0%, 100% 0%, calc(100% - 0.8rem) 50%, 100% 100%, 0% 100%, 0.8rem 50%);
  }
}
.side__bnr__img {
  position: relative;
  z-index: 1;
  display: block;
  width: 27.1rem;
  aspect-ratio: 271/146;
  margin: 0 auto;
  border-radius: 1.4rem;
  overflow: hidden;
  box-shadow: 0 0 0.8rem rgba(0, 0, 0, 0.15);
}
@media all and (max-width: 900px) {
  .side__bnr__img {
    width: auto;
    margin: 0 1rem;
    border-radius: 0.7rem;
    box-shadow: 0 0 0.4rem rgba(0, 0, 0, 0.15);
  }
}
.side__bnr__img img {
  width: 100%;
  height: 100%;
  -o-object-fit: cover;
     object-fit: cover;
}

.ttl {
  position: relative;
  padding-top: 6rem;
  display: table;
  margin: 0 auto 4.8rem;
  color: #4aa9a1;
}
@media all and (max-width: 900px) {
  .ttl {
    padding-top: 2.8rem;
    margin-bottom: 2.4rem;
  }
}
.ttl::before {
  content: "";
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  margin: 0 auto;
  background: no-repeat 0 0;
  background-size: 100% 100%;
}
.ttl__en {
  display: flex;
  align-items: center;
  justify-content: center;
  gap: 2rem;
  font-size: 2.4rem;
  font-weight: 400;
  margin-bottom: 1rem;
}
@media all and (max-width: 900px) {
  .ttl__en {
    gap: 1rem;
    font-size: 1rem;
    margin-bottom: 0.8rem;
  }
}
.ttl__en::before, .ttl__en::after {
  content: "";
  width: 13rem;
  height: 1px;
  background-color: #4aa9a1;
}
@media all and (max-width: 900px) {
  .ttl__en::before, .ttl__en::after {
    width: 5.5rem;
  }
}
.ttl__jp {
  font-size: 4.2rem;
  font-weight: 700;
  text-align: center;
  padding: 3.2rem 0;
  background: url(../images/ttl_bg_001.png) no-repeat 50% 50%;
  background-size: 16.8rem 11.2rem;
}
@media all and (max-width: 900px) {
  .ttl__jp {
    font-size: 1.8rem;
    padding: 1.4rem 0;
    background-size: 7.2rem 4.9rem;
  }
}
.ttl--about::before {
  width: 4.6rem;
  height: 4.8rem;
  background-image: url(../images/ic_about_001.png);
}
@media all and (max-width: 900px) {
  .ttl--about::before {
    width: 2rem;
    height: 2rem;
  }
}
.ttl--feature::before {
  width: 5.4rem;
  height: 4rem;
  background-image: url(../images/ic_feature_001.png);
}
@media all and (max-width: 900px) {
  .ttl--feature::before {
    width: 2rem;
    height: 2rem;
  }
}
.ttl--life::before {
  width: 5.7rem;
  height: 4.1rem;
  background-image: url(../images/ic_life_001.png);
}
@media all and (max-width: 900px) {
  .ttl--life::before {
    width: 2.5rem;
    height: 1.8rem;
  }
}
.ttl--admission::before {
  width: 5.9rem;
  height: 4.1rem;
  background-image: url(../images/ic_admission_001.png);
}
@media all and (max-width: 900px) {
  .ttl--admission::before {
    width: 2.5rem;
    height: 1.7rem;
  }
}
.ttl--blog::before {
  width: 4.1rem;
  height: 4.1rem;
  background-image: url(../images/ic_blog_001.png);
}
@media all and (max-width: 900px) {
  .ttl--blog::before {
    width: 1.7rem;
    height: 1.7rem;
  }
}
.ttl--blog::before {
  width: 4.1rem;
  height: 4.1rem;
  background-image: url(../images/ic_blog_002.png);
}
@media all and (max-width: 900px) {
  .ttl--blog::before {
    width: 1.7rem;
    height: 1.7rem;
  }
}
.ttl--news::before {
  width: 3.9rem;
  height: 4.1rem;
  background-image: url(../images/ic_news_001.png);
}
@media all and (max-width: 900px) {
  .ttl--news::before {
    width: 1.7rem;
    height: 1.8rem;
  }
}
.ttl--contact {
  color: #fff;
  margin-bottom: 1.2rem;
}
@media all and (max-width: 900px) {
  .ttl--contact {
    margin-bottom: 0.4rem;
  }
}
.ttl--contact::before {
  width: 5.4rem;
  height: 4rem;
  background-image: url(../images/ic_contact_003.png);
}
@media all and (max-width: 900px) {
  .ttl--contact::before {
    width: 2.3rem;
    height: 1.8rem;
  }
}
.ttl--contact .ttl__en::before, .ttl--contact .ttl__en::after {
  background-color: #fff;
}
.ttl--contact .ttl__jp {
  background: none;
}
.ttl--event::before {
  width: 3.7rem;
  aspect-ratio: 37/53;
  background-image: url(../images/ic_event_001.png);
}
@media all and (max-width: 900px) {
  .ttl--event::before {
    width: 1.8rem;
  }
}

.btns {
  display: flex;
  gap: 2rem;
  list-style-type: none;
  margin: 0;
}
@media all and (max-width: 900px) {
  .btns {
    flex-wrap: wrap;
    gap: 1.5rem 1.2rem;
    justify-content: center;
  }
}
.btns > li {
  flex: auto;
}
@media all and (max-width: 900px) {
  .btns > li {
    flex: none;
  }
}
.btns .btn {
  display: flex;
}

.btn {
  position: relative;
  display: inline-flex;
  align-items: center;
  color: #45ada4;
  text-decoration: none;
  font-size: 2.8rem;
  font-weight: 700;
  min-width: 24rem;
  height: 8rem;
}
@media all and (max-width: 900px) {
  .btn {
    font-size: 1.2rem;
    min-width: 12rem;
    height: 3.5rem;
  }
}
.btn::before {
  content: "";
  position: absolute;
  bottom: -0.8rem;
  right: -0.8rem;
  width: 100%;
  height: 100%;
  background-color: rgba(69, 173, 164, 0.2);
  border-radius: 4rem;
}
@media all and (max-width: 900px) {
  .btn::before {
    border-radius: 1.8rem;
    bottom: -0.4rem;
    right: -0.4rem;
  }
}
.btn__inner {
  position: relative;
  z-index: 2;
  display: flex;
  align-items: center;
  justify-content: center;
  width: 100%;
  height: 100%;
  background-color: #fff;
  border: 0.2rem solid #45ada4;
  border-radius: 4rem;
  padding: 0.8rem 4.8rem;
}
@media all and (max-width: 900px) {
  .btn__inner {
    border-radius: 1.8rem;
    padding: 0.4rem 3.2rem;
  }
}
.btn__inner::after {
  content: "";
  position: absolute;
  top: 0;
  right: 2.8rem;
  bottom: 0;
  margin: auto 0;
  width: 1.2rem;
  height: 2.4rem;
  background-color: #45ada4;
  clip-path: polygon(0% 0%, 100% 50%, 0% 100%);
}
@media all and (max-width: 900px) {
  .btn__inner::after {
    right: 1.4rem;
    width: 0.6rem;
    height: 1.1rem;
  }
}
.btn--type2 {
  color: #fff;
}
.btn--type2 .btn__inner {
  background-color: #45ada4;
}
.btn--type2 .btn__inner::after {
  background-color: #fff;
}
.mv {
  position: relative;
  width: 140rem;
  height: 104rem;
  aspect-ratio: 1920/1040;
  margin: 0 auto;
}
@media all and (max-width: 900px) {
  .mv {
    width: 100%;
    height: 42.8rem;
    aspect-ratio: 320/428;
  }
}
.mv::before {
  content: "";
  position: absolute;
  top: 0;
  left: 50%;
  z-index: 2;
  transform: translateX(-50%);
  width: 192rem;
  height: 100%;
  background: url(../images/mv_bg_001.png) no-repeat 0 0;
  background-size: 100% 100%;
  pointer-events: none;
}
@media all and (max-width: 900px) {
  .mv::before {
    left: 0;
    transform: translateX(0);
    width: 100%;
    height: 100%;
    background-image: url(../images/mv_bg_001_sp.png);
  }
}
.mv__inner {
  position: absolute;
  top: 0;
  left: 50%;
  z-index: 1;
  transform: translateX(-50%);
  width: 192rem;
  height: 100%;
  overflow: hidden;
}
@media all and (max-width: 900px) {
  .mv__inner {
    left: 0;
    transform: translateX(0);
    width: 100%;
  }
}
.mv__slides {
  width: 100%;
  height: 100%;
  opacity: 0;
}
.mv__slides.slick-initialized {
  opacity: 1;
}
.mv__slide__txt {
  position: absolute;
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  bottom: 17rem;
  left: 50%;
  z-index: 4;
  transform: translateX(-50%);
  width: 128rem;
  height: 16rem;
  background-color: rgba(255, 255, 255, 0.8);
  border-radius: 1.2rem;
  border: 0.6rem dotted #4aa9a1;
  font-size: 3.6rem;
  font-weight: 700;
  line-height: 1.4;
  color: #4aa9a1;
}
@media all and (max-width: 900px) {
  .mv__slide__txt {
    width: 28rem;
    height: 7.6rem;
    bottom: 7.6rem;
    border-radius: 0.4rem;
    border-width: 0.4rem;
    font-size: 1.5rem;
  }
}
.mv__slide__txt p {
  margin: 0;
}
.mv__slide__btn {
  position: absolute;
  bottom: 14.2rem;
  left: 50%;
  z-index: 5;
  transform: translateX(-50%);
  width: 140rem;
  text-align: right;
  margin: 0;
}
@media all and (max-width: 900px) {
  .mv__slide__btn {
    left: 0;
    right: 0;
    bottom: 5.6rem;
    transform: translateX(0);
    width: 100%;
    text-align: center;
  }
}
.mv__slide__btn a {
  position: relative;
  display: inline-flex;
  min-width: 30rem;
  max-width: 48rem;
  height: 8rem;
  color: #fff;
  text-decoration: none;
  font-size: 2.8rem;
  line-height: 1.2;
  font-weight: 700;
  text-align: left;
}
@media all and (max-width: 900px) {
  .mv__slide__btn a {
    min-width: 13.7rem;
    max-width: 26rem;
    height: 3.5rem;
    font-size: 1.3rem;
  }
}
.mv__slide__btn a::before {
  content: "";
  position: absolute;
  right: -0.8rem;
  bottom: -0.8rem;
  width: 100%;
  height: 100%;
  border-radius: 4rem;
  background-color: rgba(69, 173, 164, 0.2);
}
.mv__slide__btn__inner {
  position: relative;
  display: flex;
  align-items: center;
  justify-content: center;
  width: 100%;
  height: 100%;
  padding: 0.8rem 5.2rem;
  background-color: #45ada4;
  border-radius: 4rem;
}
@media all and (max-width: 900px) {
  .mv__slide__btn__inner {
    padding: 0.4rem 2.8rem;
    border-radius: 1.8rem;
  }
}
.mv__slide__btn__inner::after {
  content: "";
  position: absolute;
  top: 0;
  right: 2.8rem;
  bottom: 0;
  margin: auto 0;
  width: 1.3rem;
  height: 2.3rem;
  background-color: #fff;
  clip-path: polygon(0% 0%, 100% 50%, 0% 100%);
}
@media all and (max-width: 900px) {
  .mv__slide__btn__inner::after {
    right: 1.2rem;
    width: 0.7rem;
    height: 1.3rem;
  }
}
.mv__slide__img {
  position: relative;
  z-index: 3;
}
.mv__slide__img img {
  width: 100%;
  height: 100%;
  -o-object-fit: cover;
     object-fit: cover;
  -o-object-position: 50% 50%;
     object-position: 50% 50%;
}
.mv__slide__img__pc {
  display: block !important;
}
@media all and (max-width: 900px) {
  .mv__slide__img__pc {
    display: none !important;
  }
}
.mv__slide__img__sp {
  display: none !important;
}
@media all and (max-width: 900px) {
  .mv__slide__img__sp {
    display: block !important;
  }
}

/*.mv2 {
  position: relative;
  width: 100%;
  height: 40rem;
  display: flex;
  align-items: center;
  justify-content: center;
}*/

.mv2 {
    position: relative;
    width: 100%;
    height: 40rem;
    display: flex;
    align-items: center;
    justify-content: flex-start;   /* center → flex-start */
}


@media all and (max-width: 900px) {
  .mv2 {
    height: 17rem;
  }
}

/*.mv2__inner {
  position: relative;
  z-index: 3;
  text-align: center;
  color: #4aa9a1;
  line-height: 1.4;
  font-weight: 700;
  text-shadow: 0 0 1.2rem rgba(255, 255, 255, 0.65);
}*/

.mv2__inner {
    position: relative;
    z-index: 3;
    width: 100%;
    max-width: 143rem;   /* ← グローバルナビのコンテナ幅に合わせる */
    margin: 0 auto;      /* ナビと同じく中央寄せコンテナに */
    padding: 0 2rem;     /* ← ナビの左右パディングに合わせる */
    box-sizing: border-box;
    text-align: left;    /* center → left */
    color: #4aa9a1;
    line-height: 1.4;
    font-weight: 700;
    text-shadow: 0 0 1.2rem rgba(255, 255, 255, 0.65);
}

@media all and (max-width: 900px) {
  .mv2__inner {
  text-align: center;
    padding-top: 1.8rem;
       text-shadow:
 1px 0 0 #ffffff,
   -1px 0 0 #ffffff,
    0 1px 0 #ffffff,
    0 -1px 0 #ffffff,
    1px 1px 0 #ffffff,
   -1px 1px 0 #ffffff,
    1px -1px 0 #ffffff,
   -1px -1px 0 #ffffff;
        0 0 0.6rem rgba(255, 255, 255, 0.65);
  }
}
.mv2__jp {
  font-size: 4.6rem;
  margin: 0;
}
@media all and (max-width: 900px) {
  .mv2__jp {
    font-size: 2rem;
  }
}
.mv2__en {
  font-size: 2.4rem;
  margin: 0;
}
@media all and (max-width: 900px) {
  .mv2__en {
    font-size: 1.1rem;
  }
}
.mv2__img {
  position: absolute;
  inset: 0;
  z-index: 1;
}
.mv2__img img {
  width: 100%;
  height: 100%;
  -o-object-fit: cover;
     object-fit: cover;
       object-position: right center;   /* ← 追加：右端を基準に */
}
@media all and (max-width: 900px) {
  .mv2__img__pc {
    display: none;
  }
}
.mv2__img__sp {
  display: none;
}
@media all and (max-width: 900px) {
  .mv2__img__sp {
    display: block;
  }
}

.nav {
  display: flex;
  align-items: center;
  justify-content: center;
  gap: 6rem;
  margin: 0;
  list-style-type: none;
}
@media all and (max-width: 900px) {
  .nav {
    gap: 1rem;
  }
}
.nav__item {
  width: 48rem;
  height: 12rem;
}
@media all and (max-width: 900px) {
  .nav__item {
    width: 100%;
    height: 5rem;
  }
}
.nav__item a {
  position: relative;
  display: block;
  width: 100%;
  height: 100%;
  font-size: 2.4rem;
  font-weight: 700;
  text-decoration: none;
  color: #333333;
  background-color: #fff;
  box-shadow: 0 0 0.8rem rgba(0, 0, 0, 0.15);
  border-radius: 1.4rem;
}
@media all and (max-width: 900px) {
  .nav__item a {
    font-size: 1.2rem;
    box-shadow: 0 0 0.4rem rgba(0, 0, 0, 0.15);
    border-radius: 0.7rem;
  }
}
.nav__item a::before, .nav__item a::after {
  content: "";
  position: absolute;
  z-index: 2;
}
.nav__item a::before {
  top: -3.8rem;
  left: 0;
  right: 0;
  margin: 0 auto;
  width: 7.3rem;
  height: 7.3rem;
  border-radius: 50%;
}
@media all and (max-width: 900px) {
  .nav__item a::before {
    top: -1.6rem;
    width: 3.2rem;
    height: 3.2rem;
  }
}
.nav__item a::after {
  top: 1rem;
  right: 2rem;
  bottom: 0;
  margin: auto 0;
  width: 1.8rem;
  height: 3.3rem;
  clip-path: polygon(0% 0%, 100% 50%, 0% 100%);
}
@media all and (max-width: 900px) {
  .nav__item a::after {
    top: 0.5rem;
    right: 1rem;
    width: 0.7rem;
    height: 1.3rem;
  }
}
.nav__item__inner {
  position: relative;
  display: flex;
  align-items: center;
  justify-content: center;
  width: 100%;
  height: 100%;
  border-radius: 1.4rem;
  overflow: hidden;
  padding-top: 1rem;
}
@media all and (max-width: 900px) {
  .nav__item__inner {
    border-radius: 0.7rem;
    padding-top: 0.4rem;
  }
}
.nav__item__inner::before {
  content: "";
  position: absolute;
  z-index: 1;
  top: 0;
  right: 0;
  left: 0;
  height: 1rem;
}
@media all and (max-width: 900px) {
  .nav__item__inner::before {
    height: 0.4rem;
  }
}
.nav__item--event a::before {
  background: #f6c724 url(../images/ic_event_002.png) no-repeat 50% 50%;
  background-size: 3.3rem 4.7rem;
}
@media all and (max-width: 900px) {
  .nav__item--event a::before {
    background-size: 1.5rem 2.2rem;
  }
}
.nav__item--event a::after {
  background-color: #f6c724;
}
.nav__item--event .nav__item__inner::before {
  background-color: #f6c724;
}
.nav__item--day a::before {
  background: #45ada4 url(../images/ic_day_001.png) no-repeat 50% 50%;
  background-size: 4.3rem 3rem;
}
@media all and (max-width: 900px) {
  .nav__item--day a::before {
    background-size: 1.9rem 1.4rem;
  }
}
.nav__item--day a::after {
  background-color: #45ada4;
}
.nav__item--day .nav__item__inner::before {
  background-color: #45ada4;
}
.about {
  padding: 10rem 0 8rem;
  background-color: #fff;
}
@media all and (max-width: 900px) {
  .about {
    padding: 2.6rem 0 2.4rem;
  }
}
.about__container {
  position: relative;
}
.about__ttl {
  position: relative;
  z-index: 3;
}
.about__txt {
  position: relative;
  z-index: 3;
  width: 78rem;
  margin: 0 auto 9rem;
  text-align: center;
  font-size: 2.2rem;
  font-weight: 700;
  line-height: 3.4;
}
@media all and (max-width: 900px) {
  .about__txt {
    width: auto;
    font-size: 1.1rem;
    margin-bottom: 4rem;
    line-height: 3;
  }
}
.about__btn {
  position: relative;
  z-index: 3;
  margin-bottom: 10rem;
}
@media all and (max-width: 900px) {
  .about__btn {
    margin-bottom: 4rem;
  }
}
.about__btn2 {
  position: relative;
  z-index: 3;
  margin-bottom: 0;
  text-align: center;
}
.about__img {
  position: absolute;
  top: 13.4rem;
  left: -4.5rem;
}
@media all and (max-width: 900px) {
  .about__img {
    position: relative;
    top: 0;
    left: 0;
    margin-bottom: 4rem;
  }
}
.about__img::before {
  content: "";
  position: absolute;
  left: -7.6rem;
  bottom: -17rem;
  z-index: 1;
  width: 64rem;
  aspect-ratio: 701/455;
  background: url(../images/about_bg_001.png) no-repeat 0 0;
  background-size: 100% 100%;
}
@media all and (max-width: 900px) {
  .about__img::before {
    left: auto;
    right: -2rem;
    bottom: -2.4rem;
    width: 20.8rem;
    height: 24.6rem;
    background-image: url(../images/about_bg_001_sp.png);
  }
}
.about__img__inner {
  position: relative;
  z-index: 2;
  width: 42rem;
  aspect-ratio: 470/330;
  border-radius: 1.4rem;
  overflow: hidden;
}
@media all and (max-width: 900px) {
  .about__img__inner {
    width: 28rem;
    height: 17.5rem;
    border-radius: 1rem;
  }
}
.about__img img {
  width: 100%;
  height: 100%;
  -o-object-fit: cover;
     object-fit: cover;
}
.about__img2 {
  position: absolute;
  top: 24rem;
  right: -4.5rem;
}
@media all and (max-width: 900px) {
  .about__img2 {
    display: none;
  }
}
.about__img2::before {
  content: "";
  position: absolute;
  right: -12.2rem;
  bottom: -6rem;
  z-index: 1;
  width: 64rem;
  aspect-ratio: 672/568;
  background: url(../images/about_bg_002.png) no-repeat 0 0;
  background-size: 100% 100%;
}
@media all and (max-width: 900px) {
  .about__img2::before {
    display: none;
  }
}
.about__img2__inner {
  position: relative;
  z-index: 2;
  width: 42rem;
  aspect-ratio: 470/330;
  border-radius: 1.4rem;
  overflow: hidden;
}
.about__img2 img {
  width: 100%;
  height: 100%;
  -o-object-fit: cover;
     object-fit: cover;
}

.feature {
  padding: 8rem 0;
  background-color: #fff;
}
@media all and (max-width: 900px) {
  .feature {
    padding: 2.6rem 0 2.4rem;
  }
}
.feature--type2 {
  padding-top: 12rem;
}
@media all and (max-width: 900px) {
  .feature--type2 {
    padding-top: 4.8rem;
  }
}
.feature__container {
  position: relative;
}
.feature__ttl {
  position: relative;
  z-index: 3;
}
.feature__ttl2 {
  position: relative;
  z-index: 3;
  display: table;
  vertical-align: middle;
  margin: -1.2rem auto 3.2rem;
  background-color: #45ada4;
  color: #fff;
  font-size: 2.2rem;
  line-height: 1.2;
  font-weight: 700;
  height: 4.8rem;
  clip-path: polygon(0% 0%, 100% 0%, calc(100% - 1.2rem) 50%, 100% 100%, 0% 100%, 1.2rem 50%);
}
@media all and (max-width: 900px) {
  .feature__ttl2 {
    font-size: 1.2rem;
    margin: -2rem auto 2.4rem;
    height: 2.6rem;
    clip-path: polygon(0% 0%, 100% 0%, calc(100% - 0.6rem) 50%, 100% 100%, 0% 100%, 0.6rem 50%);
  }
}
.feature__ttl2__inner {
  display: flex;
  align-items: center;
  justify-content: center;
  width: 100%;
  height: 100%;
  padding: 0 3.5rem;
}
.feature__txt {
  position: relative;
  z-index: 3;
  font-size: 2.8rem;
  font-weight: 700;
  color: #4aa9a1;
  text-align: center;
  margin: 0 -4.8rem 3.2rem;
}
@media all and (max-width: 900px) {
  .feature__txt {
    font-size: 1.4rem;
    margin: 0 -1.4rem 2rem;
  }
}
.feature__txt2 {
  position: relative;
  z-index: 3;
  font-size: 1.8rem;
  margin: 0;
}
@media all and (max-width: 900px) {
  .feature__txt2 {
    font-size: 1.1rem;
  }
}
.feature__row {
  display: flex;
  flex-wrap: wrap;
  gap: 10rem 21.6rem;
  margin: 0 9.2rem;
}
@media all and (max-width: 900px) {
  .feature__row {
    flex-direction: column;
    gap: 4rem;
    margin: 0;
  }
}
.feature__col {
  width: 50rem;
}
@media all and (max-width: 900px) {
  .feature__col {
    width: auto;
  }
}
.feature__img {
  position: relative;
  width: 50rem;
  height: 50rem;
  margin: 0 auto;
}
@media all and (max-width: 900px) {
  .feature__img {
    width: 21.4rem;
    height: 21.4rem;
  }
}
.feature__img::before {
  content: "";
  position: absolute;
  z-index: 1;
  background: no-repeat 0 0;
  background-size: 100% 100%;
}
.feature__img--type1::before {
  left: -16.5rem;
  bottom: 0;
  width: 24.9rem;
  height: 21rem;
  background-image: url(../images/feature_bg_001.png);
}
@media all and (max-width: 900px) {
  .feature__img--type1::before {
    width: 10.7rem;
    height: 9rem;
    left: -3.8rem;
    bottom: 1.6rem;
  }
}
.feature__img--type2::before {
  right: -16rem;
  bottom: -5.4rem;
  width: 70.2rem;
  height: 45.5rem;
  background-image: url(../images/feature_bg_002.png);
}
@media all and (max-width: 900px) {
  .feature__img--type2::before {
    right: -4rem;
    bottom: -2.3rem;
    width: 30rem;
    height: 19.4rem;
  }
}
.feature__img--type3::before {
  left: -11.2rem;
  bottom: -3rem;
  width: 67.2rem;
  height: 44.8rem;
  background-image: url(../images/feature_bg_003.png);
}
@media all and (max-width: 900px) {
  .feature__img--type3::before {
    left: -3.8rem;
    bottom: -1.8rem;
    width: 28.7rem;
    height: 19.2rem;
  }
}
.feature__img--type4::before {
  right: -17.6rem;
  bottom: -1.4rem;
  width: 24.9rem;
  height: 21rem;
  background-image: url(../images/feature_bg_004.png);
}
@media all and (max-width: 900px) {
  .feature__img--type4::before {
    right: -4rem;
    bottom: 1.3rem;
    width: 10.7rem;
    height: 9rem;
  }
}
.feature__img--type5::before {
  left: -16.4rem;
  bottom: -1.4rem;
  width: 24.9rem;
  height: 21.2rem;
  background-image: url(../images/feature_bg_005.png);
}
@media all and (max-width: 900px) {
  .feature__img--type5::before {
    left: -3.8rem;
    bottom: 0;
    width: 10.7rem;
    height: 9.1rem;
  }
}
.feature__img--type6::before {
  right: -15.6rem;
  bottom: -6.2rem;
  width: 70.2rem;
  height: 45.4rem;
  background-image: url(../images/feature_bg_006.png);
}
@media all and (max-width: 900px) {
  .feature__img--type6::before {
    right: -4.2rem;
    bottom: -2rem;
    width: 30rem;
    height: 19.4rem;
  }
}
.feature__img__inner {
  position: relative;
  z-index: 2;
  border-radius: 50%;
  overflow: hidden;
}
.feature__img img {
  width: 100%;
  height: 100%;
  -o-object-fit: cover;
     object-fit: cover;
}
.feature__btn {
  margin: 10rem 0 0;
  text-align: center;
}
@media all and (max-width: 900px) {
  .feature__btn {
    margin-top: 4.2rem;
  }
}

.life {
  padding: 8rem 0 20rem;
  background-color: #fff;
}
@media all and (max-width: 900px) {
  .life {
    padding: 2.6rem 0 4.8rem;
  }
}
.life__container {
  position: relative;
}
.life__container::before {
  content: "";
  position: absolute;
  z-index: 1;
  top: 30rem;
  right: -20rem;
  width: 25rem;
  height: 21.1rem;
  background: url(../images/life_bg_001.png) no-repeat 0 0;
  background-size: 100% 100%;
}
@media all and (max-width: 900px) {
  .life__container::before {
    top: 8.2rem;
    right: 0;
    width: 10.7rem;
    height: 9rem;
  }
}
.life__ttl {
  position: relative;
  z-index: 3;
}
.life__ttl2 {
  position: relative;
  z-index: 3;
  font-size: 3.6rem;
  font-weight: 700;
  color: #4aa9a1;
  margin-bottom: 3rem;
}
@media all and (max-width: 900px) {
  .life__ttl2 {
    font-size: 1.5rem;
    margin-bottom: 1.8rem;
    text-align: center;
  }
}
.life__row {
  display: flex;
  align-items: center;
  gap: 6rem;
}
@media all and (max-width: 900px) {
  .life__row {
    flex-direction: column;
    gap: 4rem;
  }
}
.life__row + .life__row {
  margin-top: 10rem;
}
@media all and (max-width: 900px) {
  .life__row + .life__row {
    margin-top: 4.8rem;
  }
}
.life__col {
  position: relative;
  flex: 1;
  order: 2;
  z-index: 2;
}
@media all and (max-width: 900px) {
  .life__col {
    width: auto;
    order: 2 !important;
  }
}
.life__col2 {
  position: relative;
  width: 89.5rem;
  order: 1;
  z-index: 1;
}
@media all and (max-width: 900px) {
  .life__col2 {
    width: auto;
    order: 1 !important;
  }
}
.life__col2::before {
  content: "";
  position: absolute;
  bottom: -8.5rem;
  right: -19rem;
  width: 67.2rem;
  height: 44.9rem;
  background: url(../images/life_bg_002.png) no-repeat 0 0;
  background-size: 100% 100%;
}
@media all and (max-width: 900px) {
  .life__col2::before {
    width: 28.8rem;
    height: 19.2rem;
    bottom: -2.4rem;
    right: -2.9rem;
  }
}
.life__col2--type2::before {
  bottom: 3.2rem;
}
@media all and (max-width: 900px) {
  .life__col2--type2::before {
    bottom: -3rem;
  }
}
.life__col2--type3::before {
  bottom: -3rem;
  left: -33rem;
  width: 70.1rem;
  height: 45.5rem;
  background-image: url(../images/life_bg_003.png);
}
@media all and (max-width: 900px) {
  .life__col2--type3::before {
    bottom: -4.8rem;
    left: -7.3rem;
    width: 30rem;
    height: 19.4rem;
  }
}
.life__row--type2 .life__col {
  order: 1;
}
.life__row--type2 .life__col2 {
  order: 2;
}
.life__txt {
  font-size: 1.8rem;
  margin-bottom: 4.8rem;
}
@media all and (max-width: 900px) {
  .life__txt {
    font-size: 1.1rem;
    margin-bottom: 2rem;
  }
}
.life__btn {
  margin: 0;
}
@media all and (max-width: 900px) {
  .life__btn {
    text-align: center;
  }
}
.life__img {
  position: relative;
  z-index: 2;
  border-radius: 1.4rem;
  overflow: hidden;
  aspect-ratio: 895/535;
}
@media all and (max-width: 900px) {
  .life__img {
    border-radius: 0.8rem;
  }
}
.life__img img {
  width: 100%;
  height: 100%;
  -o-object-fit: cover;
     object-fit: cover;
}
.life__imgs {
  display: flex;
  gap: 1.8rem;
  padding-bottom: 11.2rem;
}
@media all and (max-width: 900px) {
  .life__imgs {
    gap: 0.6rem;
    padding-bottom: 3.4rem;
  }
}
.life__imgs .life__img {
  position: relative;
  aspect-ratio: 286/665;
}
.life__imgs .life__img:nth-child(2) {
  top: 11.2rem;
}
@media all and (max-width: 900px) {
  .life__imgs .life__img:nth-child(2) {
    top: 3.4rem;
  }
}

.admission {
  padding: 9rem 0 21rem;
  background-color: #fffdea;
}
@media all and (max-width: 900px) {
  .admission {
    padding: 2.6rem 0 4.8rem;
  }
}
.admission__container {
  position: relative;
}
.admission__ttl {
  position: relative;
  z-index: 3;
}
.admission__ttl2 {
  border-bottom: 0.2rem solid #4aa9a1;
  font-size: 3.6rem;
  font-weight: 700;
  margin-bottom: 4rem;
}
@media all and (max-width: 900px) {
  .admission__ttl2 {
    font-size: 1.5rem;
    text-align: center;
    margin-bottom: 1rem;
    border-bottom-width: 1px;
  }
}
.admission__ttl2 a {
  position: relative;
  display: block;
  padding: 0 4.8rem 2rem 6.4rem;
  color: #4aa9a1;
  text-decoration: none;
}
@media all and (max-width: 900px) {
  .admission__ttl2 a {
    padding: 0 2.8rem 1rem;
  }
}
.admission__ttl2 a::before {
  content: "";
  position: absolute;
  top: 0.8rem;
  left: 0;
  width: 4.6rem;
  height: 4.8rem;
  background: url(../images/ic_about_001.png) no-repeat 0 0;
  background-size: 100% 100%;
}
@media all and (max-width: 900px) {
  .admission__ttl2 a::before {
    top: 0.2rem;
    width: 2rem;
    height: 2rem;
  }
}
.admission__ttl2 a::after {
  content: "";
  position: absolute;
  top: 2.2rem;
  right: 2rem;
  width: 1.2rem;
  height: 2.3rem;
  background-color: #45ada4;
  clip-path: polygon(0% 0%, 100% 50%, 0% 100%);
}
@media all and (max-width: 900px) {
  .admission__ttl2 a::after {
    top: 0.8rem;
    right: 0;
    width: 0.8rem;
    height: 1.1rem;
  }
}
.admission__ttl3 {
  display: table;
  margin: 0 auto 2.8rem;
  padding: 0.8rem 4rem;
  background-color: #45ada4;
  color: #fff;
  font-size: 2.8rem;
  text-align: center;
  clip-path: polygon(0% 0%, 100% 0%, calc(100% - 1.2rem) 50%, 100% 100%, 0% 100%, 1.2rem 50%);
}
@media all and (max-width: 900px) {
  .admission__ttl3 {
    margin-bottom: 2.4rem;
    padding: 0.4rem 1.8rem;
    font-size: 1.2rem;
    clip-path: polygon(0% 0%, 100% 0%, calc(100% - 0.6rem) 50%, 100% 100%, 0% 100%, 0.6rem 50%);
  }
}
.admission__row {
  position: relative;
  display: flex;
  gap: 6rem;
  margin-bottom: 8.4rem;
}
@media all and (max-width: 900px) {
  .admission__row {
    flex-direction: column;
    gap: 4.8rem;
    margin-bottom: 4.2rem;
  }
}
.admission__col {
  position: relative;
  z-index: 2;
  flex: 1;
}
.admission__col2 {
  position: relative;
  width: 77rem;
}
@media all and (max-width: 900px) {
  .admission__col2 {
    width: auto;
  }
}
.admission__col2::before {
  content: "";
  position: absolute;
  top: -4.8rem;
  right: -13.6rem;
  z-index: 1;
  width: 25rem;
  height: 21rem;
  background: url(../images/admission_bg_001.png) no-repeat 0 0;
  background-size: 100% 100%;
}
@media all and (max-width: 900px) {
  .admission__col2::before {
    top: -1rem;
    right: -5.7rem;
    width: 10.7rem;
    height: 9rem;
  }
}
.admission__col2__inner {
  position: relative;
  z-index: 2;
}
.admission__txt {
  margin: 0;
  font-size: 1.8rem;
}
@media all and (max-width: 900px) {
  .admission__txt {
    font-size: 1.1rem;
  }
}
.admission__btn {
  margin-top: 2rem;
}
.admission__movie {
  aspect-ratio: 770/433;
  border-radius: 1.4rem;
  overflow: hidden;
}
@media all and (max-width: 900px) {
  .admission__movie {
    border-radius: 0.8rem;
  }
}
.admission__movie iframe {
  width: 100%;
  height: 100%;
}
.admission__guide {
  position: relative;
}
@media all and (max-width: 900px) {
  .admission__guide {
    padding-top: 16.8rem;
  }
}
.admission__guide__link {
  position: relative;
  display: flex;
  align-items: center;
  height: 26rem;
  background-color: #e25b6b;
  border-radius: 1.4rem;
  padding: 0 9rem 0 63rem;
  text-decoration: none;
  color: #fff;
}
@media all and (max-width: 900px) {
  .admission__guide__link {
    height: auto;
    border-radius: 0.8rem;
    padding: 2.4rem 4.8rem 2.4rem 2rem;
  }
}
.admission__guide__link::before {
  content: "";
  position: absolute;
  inset: 1rem;
  border-radius: 1rem;
  border: 0.2rem solid #fff;
  pointer-events: none;
}
@media all and (max-width: 900px) {
  .admission__guide__link::before {
    inset: 0.4rem;
    border-radius: 0.4rem;
  }
}
.admission__guide__link::after {
  content: "";
  position: absolute;
  top: 0;
  bottom: 0;
  right: 5.8rem;
  margin: auto 0;
  width: 2.2rem;
  height: 4.1rem;
  background-color: #fff;
  clip-path: polygon(0% 0%, 100% 50%, 0% 100%);
}
@media all and (max-width: 900px) {
  .admission__guide__link::after {
    right: 2.2rem;
    width: 1rem;
    height: 1.8rem;
  }
}
.admission__guide__ttl {
  font-size: 4.2rem;
  font-weight: 700;
  margin-bottom: 1.6rem;
}
@media all and (max-width: 900px) {
  .admission__guide__ttl {
    text-align: center;
    font-size: 1.8rem;
    margin-bottom: 1rem;
  }
}
.admission__guide__txt {
  font-size: 1.8rem;
  margin-bottom: 0;
}
@media all and (max-width: 900px) {
  .admission__guide__txt {
    font-size: 1.1rem;
  }
}
.admission__guide__img {
  position: absolute;
  top: -5.2rem;
  left: 6rem;
  width: 52.4rem;
  height: 36rem;
  border-radius: 1.4rem;
}
@media all and (max-width: 900px) {
  .admission__guide__img {
    top: 0;
    left: -2rem;
    right: -2rem;
    width: auto;
    height: 14.2rem;
    border-radius: 0;
  }
}
@media all and (max-width: 900px) {
  .admission__guide__img__pc {
    display: none;
  }
}
.admission__guide__img__sp {
  display: none;
}
@media all and (max-width: 900px) {
  .admission__guide__img__sp {
    display: block;
  }
}
.admission__guide__img img {
  width: 100%;
  height: 100%;
  -o-object-fit: cover;
     object-fit: cover;
}

.blog {
  padding: 9rem 0 21rem;
  background-color: #f3faf9;
}

.page_bg_white{
  background-color: #fff !important;
  padding: 0 !important;
  margin: 15rem 0 0rem 0;
}

@media all and (max-width: 900px) {
  .blog {
    padding: 2.6rem 0 4.8rem;
  }
.page_bg_white{
margin: 5.5rem 0 0 0 !important;
padding: 0 0 3.5rem 0 !important;
}
}
.blog__container {
  position: relative;
}
.blog__ttl {
  position: relative;
  z-index: 3;
}
.blog__slide {
  position: relative;
  margin: 0 -2rem;
  padding-bottom: 5rem;
}
.blog__slide__item {
  padding: 0 2rem;
}
.blog__slide__item a {
  text-decoration: none;
}
.blog__slide__img {
  margin-bottom: 3.6rem;
  aspect-ratio: 440/290;
  border-radius: 1.4rem;
  overflow: hidden;
}
@media all and (max-width: 900px) {
  .blog__slide__img {
    margin-bottom: 2rem;
    border-radius: 0.8rem;
  }
}
.blog__slide__img img {
  width: 100%;
  height: 100%;
  -o-object-fit: cover;
     object-fit: cover;
}
.blog__slide__date {
  margin-bottom: 1.6rem;
  color: #45ada4;
  font-size: 1.8rem;
  text-align: center;
}
@media all and (max-width: 900px) {
  .blog__slide__date {
    margin-bottom: 1rem;
    font-size: 1.1rem;
  }
}
.blog__slide__txt {
  margin-bottom: 0;
  color: #132c42;
  font-size: 1.8rem;
  text-align: center;
}
@media all and (max-width: 900px) {
  .blog__slide__txt {
    font-size: 1.1rem;
  }
}
.blog__slide .slick-arrow {
  position: absolute;
  top: -10rem;
  width: 5rem;
  height: 5rem;
  background: none;
  outline: none;
  text-indent: -999rem;
  border: 0.2rem solid #45ada4;
  border-radius: 50%;
  cursor: pointer;
  transition-duration: 0.3s;
}
@media all and (max-width: 900px) {
  .blog__slide .slick-arrow {
    top: auto;
    bottom: 0;
    width: 3rem;
    height: 3rem;
  }
}
.blog__slide .slick-arrow:hover {
  opacity: 0.8;
}
.blog__slide .slick-arrow::before, .blog__slide .slick-arrow::after {
  content: "";
  position: absolute;
  top: calc(50% - 0.1rem);
  left: calc(50% - 0.8rem);
  width: 1.6rem;
  height: 0.2rem;
  border-radius: 9999px;
  background-color: #45ada4;
  transform-origin: calc(100% - 0.1rem) 50%;
}
@media all and (max-width: 900px) {
  .blog__slide .slick-arrow::before, .blog__slide .slick-arrow::after {
    width: 1rem;
    left: calc(50% - 0.5rem);
  }
}
.blog__slide .slick-arrow::before {
  transform: rotate(42.5deg);
}
.blog__slide .slick-arrow::after {
  transform: rotate(-42.5deg);
}
.blog__slide .slick-prev {
  right: 8.6rem;
}
@media all and (max-width: 900px) {
  .blog__slide .slick-prev {
    right: auto;
    left: 11.6rem;
  }
.blog.page_bg_white .blog__slide .slick-prev {
  left: 8rem;
}
}
.blog__slide .slick-prev::before, .blog__slide .slick-prev::after {
  transform-origin: 1px 50%;
}
.blog__slide .slick-next {
  right: 2rem;
}
@media all and (max-width: 900px) {
  .blog__slide .slick-next {
    right: 11.6rem;
  }
.blog.page_bg_white .blog__slide .slick-next {
  right: 8rem;
}
}
.blog__slide .slick-next::before, .blog__slide .slick-next::after {
  transform-origin: calc(100% - 0.1rem) 50%;
}
.blog__btn {
  text-align: center;
  margin: 10rem 0 0;
}
@media all and (max-width: 900px) {
  .blog__btn {
    margin-top: 4.2rem;
  }
}

.news {
  padding: 9rem 0 21rem;
  background-color: #fff;
}
.blog-toppage {
  padding: 0 !important;

}

@media all and (max-width: 900px) {
  .news {
    padding: 2.6rem 0 4.8rem;
  }
}
.news__container {
  position: relative;
}
.news__ttl {
  position: relative;
  z-index: 3;
}
.news__list {
  border-top: 1px solid #99b6b2;
  list-style-type: none;
}
.news__list__item {
  border-bottom: 1px solid #99b6b2;
}
.news__list__item > a {
  display: flex;
  padding: 4.2rem 6rem;
  text-decoration: none;
}
@media all and (max-width: 900px) {
  .news__list__item > a {
    flex-direction: column;
    align-items: center;
    gap: 1rem;
    padding: 1.2rem 0 1.6rem;
  }
}
.news__list__date {
  width: 19rem;
  padding: 0.1rem 2.4rem 0 0;
  font-size: 1.8rem;
  color: #45ada4;
}
@media all and (max-width: 900px) {
  .news__list__date {
    width: auto;
    padding: 0;
    font-size: 1.1rem;
  }
}
.news__list__txt {
  flex: 1;
  font-size: 2rem;
  color: #132c42;
}
@media all and (max-width: 900px) {
  .news__list__txt {
    font-size: 1.1rem;
  }
}
.news__btn {
  text-align: center;
  margin: 10rem 0 0;
}
@media all and (max-width: 900px) {
  .news__btn {
    margin-top: 4.2rem;
  }
}

.contact {
  padding: 9rem 0;
  background: url(../images/contact_bg001.jpg) no-repeat 50% 0;
  background-size: cover;
  height: 130.5rem;
}
@media all and (max-width: 900px) {
  .contact {
    padding: 4rem 0;
    background-image: url(../images/contact_bg001_sp.jpg);
    height: 56.5rem;
  }
}
.contact__container {
  position: relative;
}
.contact__ttl {
  position: relative;
  z-index: 3;
}
.contact__txt {
  margin-bottom: 7.2rem;
  font-size: 1.8rem;
  color: #fff;
  text-align: center;
}
@media all and (max-width: 900px) {
  .contact__txt {
    margin-bottom: 3.6rem;
    font-size: 1.1rem;
  }
}
.contact__btns {
  display: flex;
  gap: 4rem;
  list-style-type: none;
}
@media all and (max-width: 900px) {
  .contact__btns {
    flex-direction: column;
    gap: 1.6rem;
  }
}
.contact__btns > li {
  flex: 1;
}
.contact__btn {
  position: relative;
  display: flex;
  align-items: center;
  justify-content: center;
  height: 16.2rem;
  background-color: #fff;
  text-decoration: none;
  border-radius: 1.4rem;
  box-shadow: 0 0 0.8rem rgba(0, 0, 0, 0.15);
}
@media all and (max-width: 900px) {
  .contact__btn {
    height: 6.8rem;
    border-radius: 0.8rem;
    box-shadow: 0 0 0.4rem rgba(0, 0, 0, 0.15);
  }
}
.contact__btn__tel {
  display: flex;
  align-items: center;
  justify-content: center;
  gap: 2rem;
  line-height: 1;
}
@media all and (max-width: 900px) {
  .contact__btn__tel {
    gap: 0.8rem;
  }
}
.contact__btn__tel__label {
  background-color: #289bc0;
  color: #fff;
  font-size: 1.8rem;
  font-weight: 700;
  padding: 0.6rem 1.6rem;
}
@media all and (max-width: 900px) {
  .contact__btn__tel__label {
    font-size: 1rem;
    padding: 0.2rem 0.8rem;
  }
}
.contact__btn__tel__number {
  font-size: 4.8rem;
  color: #289bc0;
}
@media all and (max-width: 900px) {
  .contact__btn__tel__number {
    font-size: 2rem;
  }
}
.contact__btn__time {
  margin-top: 1.6rem;
  font-size: 1.8rem;
  color: #132c42;
  text-align: center;
}
@media all and (max-width: 900px) {
  .contact__btn__time {
    margin-top: 0.4rem;
    font-size: 1rem;
  }
}
.contact__btn__web {
  display: flex;
  align-items: center;
  justify-content: center;
  height: 100%;
  font-size: 3.6rem;
  font-weight: 700;
  color: #289bc0;
  padding: 0 7.2rem;
}
@media all and (max-width: 900px) {
  .contact__btn__web {
    font-size: 1.5rem;
    padding: 0 3.2rem;
  }
}
.contact__btn__web::before {
  content: "";
  position: absolute;
  top: 0;
  right: 3.4rem;
  bottom: 0;
  margin: auto 0;
  width: 1.8rem;
  height: 3.3rem;
  background-color: #289bc0;
  clip-path: polygon(0% 0%, 100% 50%, 0% 100%);
}
@media all and (max-width: 900px) {
  .contact__btn__web::before {
    right: 1.2rem;
    width: 0.8rem;
    height: 1.4rem;
    background-color: #289bc0;
  }
}

.policy {
  padding: 8rem 0;
  background-color: #fff;
}
@media all and (max-width: 900px) {
  .policy {
    padding: 2.6rem 0;
  }
}
.policy__ttl {
  position: relative;
  z-index: 3;
}
.policy__row {
  display: flex;
  align-items: center;
  gap: 6rem;
}
@media all and (max-width: 900px) {
  .policy__row {
    flex-direction: column;
    align-items: flex-start;
    gap: 3.6rem;
  }
}
.policy__col {
  position: relative;
  z-index: 2;
  flex: 1;
  order: 2;
}
.policy__col2 {
  position: relative;
  z-index: 1;
  order: 1;
  width: 85.5rem;
}
@media all and (max-width: 900px) {
  .policy__col2 {
    width: auto;
  }
}
.policy__col2::before {
  content: "";
  position: absolute;
  bottom: -9rem;
  right: -9.6rem;
  width: 67.2rem;
  height: 44.9rem;
  aspect-ratio: 672/449;
  background: url(../images/policy_bg_001.png) no-repeat 0 0;
  background-size: 100% 100%;
}
@media all and (max-width: 900px) {
  .policy__col2::before {
    width: 26rem;
    height: auto;
    right: -5.8rem;
    bottom: -2.6rem;
  }
}
.policy__txt {
  margin: 0;
  font-size: 2.2rem;
  font-weight: 700;
}
@media all and (max-width: 900px) {
  .policy__txt {
    font-size: 1.1rem;
  }
}
.policy__img {
  position: relative;
  z-index: 2;
  width: 100%;
  aspect-ratio: 855/495;
  border-radius: 1.4rem;
  overflow: hidden;
}
.policy__img img {
  width: 100%;
  height: 100%;
  -o-object-fit: cover;
     object-fit: cover;
}

.goal {
  padding: 8rem 0;
  background-color: #fff;
}
@media all and (max-width: 900px) {
  .goal {
    padding: 2.6rem 0;
  }
}
.goal__ttl {
  position: relative;
  z-index: 3;
}
.goal__list {
  margin: 0;
  border-top: 0.2rem solid #a7c0bc;
  list-style-type: none;
}
.goal__list__item {
  display: flex;
  align-items: center;
  gap: 1.2rem;
  padding: 4rem 6rem;
  border-bottom: 0.2rem solid #a7c0bc;
}
@media all and (max-width: 900px) {
  .goal__list__item {
    flex-direction: column;
    align-items: flex-start;
    gap: 0.6rem;
    padding: 1.4rem 0;
  }
}
.goal__list__label {
  width: 8.5rem;
  background-color: #45ada4;
  color: #fff;
  text-align: center;
  font-size: 1.8rem;
  font-weight: 700;
  line-height: 1;
  padding: 0.8rem;
  border-radius: 0.4rem;
}
@media all and (max-width: 900px) {
  .goal__list__label {
    width: 6rem;
    font-size: 1rem;
    padding: 0.6rem;
    border-radius: 0.2rem;
  }
}
.goal__list__txt {
  flex: 1;
  font-size: 2.2rem;
  font-weight: 700;
}
@media all and (max-width: 900px) {
  .goal__list__txt {
    font-size: 1.1rem;
  }
}

.goal2 {
  padding: 8rem 0;
  background-color: #fff;
}
@media all and (max-width: 900px) {
  .goal2 {
    padding: 2.6rem 0 5.2rem;
  }
}
.goal2__ttl {
  position: relative;
  z-index: 3;
}

.goal2__main{
text-align: center;
margin: 20rem 0 0 0;

}
.goal2__ttl2 {
  text-align: center;
  margin-bottom: 4.8rem;
/*padding-right: 85.5rem; */
  font-size: 3.2rem;
  font-weight: 700;
  color: #4aa9a1;
}
@media all and (max-width: 900px) {
  .goal2__ttl2 {
    margin-bottom: 1.4rem;
    padding-right: 0;
    font-size: 1.5rem;
  }

  .goal2__main{
text-align: center;
margin: 0;
}

}
.goal2__row {
  position: relative;
  margin: 18.4rem 0 10rem;
}



@media all and (max-width: 900px) {
  .goal2__row {
    margin: 0 0 4rem;
  }
}
.goal2__img {
  position: absolute;
  z-index: 2;
  top: -11.8rem;
  right: 0;
  width: 85.5rem;
  height: 59.5rem;
  border-radius: 1.4rem;
  overflow: hidden;
}
@media all and (max-width: 900px) {
  .goal2__img {
    position: relative;
    top: 0;
    width: 100%;
    height: auto;
    aspect-ratio: 855/595;
    border-radius: 0.7rem;
  }
}
.goal2__img img {
  width: 100%;
  height: 100%;
  -o-object-fit: cover;
     object-fit: cover;
}
.goal2__txt {
  position: relative;
  z-index: 1;
  display: flex;
  align-items: center;
  height: 36rem;
  margin: 0 -100vw;
  background-color: #fffce0;
  font-size: 4.2rem;
  font-style: italic;
  font-weight: 700;
  color: #4aa9a1;
}
@media all and (max-width: 900px) {
  .goal2__txt {
    font-size: 1.7rem;
    text-align: center;
    margin: -3.6rem -2rem 0;
    padding: 5.6rem 2rem 2rem;
    height: auto;
  }
}
.goal2__txt__inner {
  width: 140rem;
  margin: 0 auto;
}
.goal2__txt2 {
  text-align: center;
/*  margin-bottom: 0; */
    margin: 0 0 4rem 4.3rem;
  font-size: 2.2rem;
  font-weight: 700;
}
@media all and (max-width: 900px) {
  .goal2__txt2 {
      margin: 0 0 2rem 0;
    font-size: 1.1rem;
  }
}

.event {
  padding: 14.8rem 0 16.4rem;
  background-color: #fffdee;
}
@media all and (max-width: 900px) {
  .event {
    padding: 7.2rem 0 4.8rem;
  }
}
.event__container {
  position: relative;
}
.event__ttl {
  position: relative;
  z-index: 3;
}
.event__nav {
  margin: 0 0 6.8rem;
}
@media all and (max-width: 900px) {
  .event__nav {
    margin-bottom: 3.2rem;
  }
}
.event__nav2 {
  margin: 25rem 0 0;
}
@media all and (max-width: 900px) {
  .event__nav2 {
    margin-top: 6.4rem;
  }
}
.event__schedule {
  position: relative;
  margin: 0 49.4rem 6.6rem;
}
@media all and (max-width: 900px) {
  .event__schedule {
    margin: 0 0 4rem;
  }
}
.event__schedule__ttl {
  position: relative;
  z-index: 2;
  display: flex;
  align-items: center;
  justify-content: center;
  width: 8rem;
  height: 8rem;
  border-radius: 50%;
  background-color: #f6c724;
  font-size: 2.4rem;
  font-weight: 700;
  color: #fff;
  margin: 0 auto 2.4rem;
}
@media all and (max-width: 900px) {
  .event__schedule__ttl {
    width: 4rem;
    height: 4rem;
    font-size: 1.5rem;
    margin-bottom: 1.2rem;
  }
}
.event__schedule__list {
  position: relative;
  z-index: 2;
  display: flex;
  flex-direction: column;
  gap: 2rem;
  list-style-type: none;
  margin: 0;
}
@media all and (max-width: 900px) {
  .event__schedule__list {
    gap: 1.2rem;
  }
}
.event__schedule__list__item {
  padding: 1.3rem 1.4rem;
  background-color: #fff;
  border-radius: 1rem;
  box-shadow: 0 0 0.8rem rgba(0, 0, 0, 0.15);
  font-size: 2rem;
  font-weight: 700;
  color: #333333;
  text-align: center;
}
@media all and (max-width: 900px) {
  .event__schedule__list__item {
    font-size: 1.4rem;
    padding: 1rem;
    border-radius: 0.5rem;
    box-shadow: 0 0 0.4rem rgba(0, 0, 0, 0.15);
  }
}
.event__schedule__img {
  position: absolute;
}
@media all and (max-width: 900px) {
  .event__schedule__img {
    position: relative;
    top: 0 !important;
    left: 0 !important;
  }
}
.event__schedule__img::before {
  content: "";
  position: absolute;
  z-index: 1;
  background: no-repeat 0 0;
  background-size: 100% 100%;
}
.event__schedule__img--type1::before {
  bottom: -11rem;
  left: -14rem;
  width: 70.2rem;
  aspect-ratio: 702/454;
  background-image: url(../images/event_bg_001.png);
}
@media all and (max-width: 900px) {
  .event__schedule__img--type1::before {
    bottom: -4.2rem;
    left: -7.3rem;
    width: 30rem;
  }
}
.event__schedule__img--type2::before {
  top: -11.4rem;
  right: -10rem;
  width: 24.9rem;
  aspect-ratio: 249/211;
  background-image: url(../images/event_bg_002.png);
}
@media all and (max-width: 900px) {
  .event__schedule__img--type2::before {
    top: -2.4rem;
    right: -2.4rem;
    width: 10.7rem;
  }
}
.event__schedule__img--type3::before {
  bottom: -8.2rem;
  left: -10rem;
  width: 25rem;
  aspect-ratio: 250/211;
  background-image: url(../images/event_bg_003.png);
}
@media all and (max-width: 900px) {
  .event__schedule__img--type3::before {
    bottom: -2.4rem;
    left: -3.8rem;
    width: 10.7rem;
  }
}
.event__schedule__img--type4::before {
  bottom: -5.2rem;
  right: -14rem;
  width: 67.2rem;
  aspect-ratio: 672/449;
  background-image: url(../images/event_bg_004.png);
}
@media all and (max-width: 900px) {
  .event__schedule__img--type4::before {
    bottom: -3rem;
    right: -3rem;
    width: 28.8rem;
  }
}
.event__schedule__img__inner {
  position: relative;
  z-index: 2;
  border-radius: 1.4rem;
  overflow: hidden;
  width: 49.2rem;
  aspect-ratio: 492/345;
}
@media all and (max-width: 900px) {
  .event__schedule__img__inner {
    border-radius: 0.7rem;
    width: auto;
    margin-top: 1.2rem;
  }
}
.event__schedule__img img {
  width: 100%;
  height: 100%;
  -o-object-fit: cover;
     object-fit: cover;
}
.event__schedule--april .event__schedule__img {
  top: 0;
  left: -53rem;
}
.event__schedule--may .event__schedule__img {
  top: -20.8rem;
  right: -53rem;
}
.event__schedule--june .event__schedule__img {
  top: -1.4rem;
  left: -53rem;
}
.event__schedule--july .event__schedule__img {
  top: -14rem;
  right: -53rem;
}
.event__schedule--august .event__schedule__img {
  top: 6rem;
  left: -53rem;
}
.event__schedule--september .event__schedule__img {
  top: -5.8rem;
  right: -53rem;
}
.event__schedule--october .event__schedule__img {
  top: 21.7rem;
  left: -53rem;
}
.event__schedule--november .event__schedule__img {
  top: 1.1rem;
  right: -53rem;
}
.event__schedule--december .event__schedule__img {
  top: 20.6rem;
  left: -53rem;
}
.event__schedule--january .event__schedule__img {
  top: 0;
  right: -53rem;
}
.event__schedule--february .event__schedule__img {
  top: 19.5rem;
  left: -53rem;
}
.event__schedule--march .event__schedule__img {
  top: -10rem;
  right: -53rem;
}
.event__birthday {
  margin: 16rem 0 25rem;
  display: flex;
  align-items: center;
  gap: 6rem;
}
@media all and (max-width: 900px) {
  .event__birthday {
    flex-direction: column;
    gap: 2.4rem;
    margin: 6.4rem 0;
  }
}
.event__birthday__col {
  position: relative;
  z-index: 2;
  flex: 1;
}
.event__birthday__col2 {
  position: relative;
  width: 89.5rem;
}
@media all and (max-width: 900px) {
  .event__birthday__col2 {
    width: auto;
  }
}
.event__birthday__col2::before, .event__birthday__col2::after {
  content: "";
  position: absolute;
  z-index: 1;
  background: no-repeat 0 0;
  background-size: 100% 100%;
}
.event__birthday__col2::before {
  top: -8.8rem;
  right: -12.2rem;
  width: 24.9rem;
  aspect-ratio: 249/211;
  background-image: url(../images/event_bg_002.png);
}
@media all and (max-width: 900px) {
  .event__birthday__col2::before {
    top: -2.4rem;
    right: -2.4rem;
    width: 10.7rem;
  }
}
.event__birthday__col2::after {
  bottom: -14.4rem;
  left: -12.6rem;
  width: 70.1rem;
  aspect-ratio: 701/455;
  background-image: url(../images/event_bg_001.png);
}
@media all and (max-width: 900px) {
  .event__birthday__col2::after {
    bottom: -4.2rem;
    left: -7.3rem;
    width: 30rem;
  }
}
.event__birthday__ttl {
  font-size: 3.6rem;
  font-weight: 700;
  color: #4aa9a1;
  margin: 0 0 2.4rem;
}
@media all and (max-width: 900px) {
  .event__birthday__ttl {
    font-size: 1.8rem;
    text-align: center;
    margin-bottom: 1.2rem;
  }
}
.event__birthday__txt {
  margin: 0;
  font-size: 1.8rem;
}
@media all and (max-width: 900px) {
  .event__birthday__txt {
    font-size: 1.2rem;
  }
}
.event__birthday__txt + .event__birthday__txt {
  margin-top: 3rem;
}
@media all and (max-width: 900px) {
  .event__birthday__txt + .event__birthday__txt {
    margin-top: 1.6rem;
  }
}
.event__birthday__img {
  position: relative;
  z-index: 2;
  width: 100%;
  aspect-ratio: 895/535;
  border-radius: 1.4rem;
  overflow: hidden;
}
@media all and (max-width: 900px) {
  .event__birthday__img {
    border-radius: 0.7rem;
  }
}
.event__birthday__img img {
  width: 100%;
  height: 100%;
  -o-object-fit: cover;
     object-fit: cover;
}

.day {
  padding: 14.8rem 0 16.4rem;
  background-color: #f3faf9;
}
@media all and (max-width: 900px) {
  .day {
    padding: 7.2rem 0 4.8rem;
  }
}
.day__container {
  position: relative;
}
.day__ttl {
  position: relative;
  z-index: 3;
}
.day__nav {
  margin: 0 0 14.8rem;
}
@media all and (max-width: 900px) {
  .day__nav {
    margin-bottom: 3.2rem;
  }
}
.day__nav2 {
  margin: 25rem 0 0;
}
@media all and (max-width: 900px) {
  .day__nav2 {
    margin-top: 6.4rem;
  }
}
.day__schedule {
  position: relative;
  display: flex;
  align-items: center;
  gap: 6rem;
  margin-bottom: 22rem;
}
@media all and (max-width: 900px) {
  .day__schedule {
    flex-direction: column;
    gap: 2rem;
    margin: 0 0 4.8rem;
  }
}
.day__schedule__col {
  flex: 1;
  position: relative;
  z-index: 2;
}
@media all and (max-width: 900px) {
  .day__schedule__col {
    order: 1 !important;
  }
}
.day__schedule__col2 {
  position: relative;
  width: 89.5rem;
}
@media all and (max-width: 900px) {
  .day__schedule__col2 {
    width: auto;
    order: 2 !important;
  }
}
.day__schedule__col2::before, .day__schedule__col2::after {
  content: "";
  position: absolute;
  z-index: 1;
  background: no-repeat 0 0;
  background-size: 100% 100%;
}
.day__schedule__col2::before {
  top: -8.7rem;
  right: -12rem;
  width: 24.9rem;
  aspect-ratio: 249/211;
  background-image: url(../images/day_bg_001.png);
}
@media all and (max-width: 900px) {
  .day__schedule__col2::before {
    top: -2.4rem;
    right: -2.4rem;
    width: 10.7rem;
  }
}
.day__schedule__col2::after {
  bottom: -15.8rem;
  left: -6.4rem;
  width: 70.1rem;
  aspect-ratio: 701/455;
  background-image: url(../images/day_bg_002.png);
}
@media all and (max-width: 900px) {
  .day__schedule__col2::after {
    bottom: -4.2rem;
    left: -7.3rem;
    width: 30rem;
  }
}
.day__schedule--type2 .day__schedule__col {
  order: 2;
}
.day__schedule--type2 .day__schedule__col2 {
  order: 1;
}
.day__schedule--type2 .day__schedule__col2::before {
  right: auto;
  left: -12rem;
}
@media all and (max-width: 900px) {
  .day__schedule--type2 .day__schedule__col2::before {
    left: -2.4rem;
  }
}
.day__schedule--type2 .day__schedule__col2::after {
  bottom: -14.6rem;
  left: -12.4rem;
  width: 67.2rem;
  aspect-ratio: 672/448;
  background-image: url(../images/day_bg_002.png);
}
@media all and (max-width: 900px) {
  .day__schedule--type2 .day__schedule__col2::after {
    left: auto;
    bottom: -3rem;
    right: -3rem;
    width: 28.8rem;
  }
}
.day__schedule--type3 {
  gap: 4rem;
}
.day__schedule--type3 .day__schedule__col2 {
  width: 64rem;
}
@media all and (max-width: 900px) {
  .day__schedule--type3 .day__schedule__col2 {
    width: auto;
  }
}
.day__schedule__img {
  position: relative;
  z-index: 2;
  border-radius: 1.4rem;
  overflow: hidden;
  width: 89.5rem;
  aspect-ratio: 895/535;
}
@media all and (max-width: 900px) {
  .day__schedule__img {
    border-radius: 0.7rem;
    width: auto;
  }
}
.day__schedule__img--type2 {
  width: 64rem;
  aspect-ratio: 640/535;
}
@media all and (max-width: 900px) {
  .day__schedule__img--type2 {
    width: auto;
  }
}
.day__schedule img {
  width: 100%;
  height: 100%;
  -o-object-fit: cover;
     object-fit: cover;
}
.day__schedule__ttl {
  display: flex;
  align-items: center;
  gap: 2rem;
  margin-bottom: 3rem;
}
@media all and (max-width: 900px) {
  .day__schedule__ttl {
    gap: 0.8rem;
    margin-bottom: 1.2rem;
  }
}
.day__schedule__ttl__time {
  position: relative;
  z-index: 2;
  display: flex;
  align-items: center;
  justify-content: center;
  width: 9.1rem;
  height: 9.1rem;
  border-radius: 50%;
  background-color: #45ada4;
  font-size: 2.4rem;
  font-weight: 700;
  color: #fff;
}
@media all and (max-width: 900px) {
  .day__schedule__ttl__time {
    width: 4rem;
    height: 4rem;
    font-size: 1.2rem;
  }
}
.day__schedule__ttl__time--type2 {
  width: auto;
  height: 6.4rem;
  padding: 0 2.4rem;
  border-radius: 3.2rem;
}
@media all and (max-width: 900px) {
  .day__schedule__ttl__time--type2 {
    height: 4rem;
    padding: 0 1rem;
    border-radius: 2rem;
  }
}
.day__schedule__ttl__txt {
  flex: 1;
  font-size: 3.6rem;
  font-weight: 700;
  color: #45ada4;
}
@media all and (max-width: 900px) {
  .day__schedule__ttl__txt {
    font-size: 1.8rem;
  }
}
.day__schedule__ttl__txt span {
  display: block;
  font-size: 2.2rem;
}
@media all and (max-width: 900px) {
  .day__schedule__ttl__txt span {
    font-size: 1.1rem;
  }
}
.day__schedule__txt {
  margin: 0;
  font-size: 1.8rem;
  color: #132c42;
}
@media all and (max-width: 900px) {
  .day__schedule__txt {
    font-size: 1.1rem;
  }
}
.day__schedule__list {
  display: flex;
  flex-wrap: wrap;
  gap: 0.6rem 0;
  margin: 3.2rem 0;
  font-size: 1.8rem;
  color: #132c42;
}
@media all and (max-width: 900px) {
  .day__schedule__list {
    margin: 1.8rem 0;
    font-size: 1.1rem;
  }
}
.day__schedule__list > dt {
  position: relative;
  width: 14rem;
  padding-right: 3rem;
}
@media all and (max-width: 900px) {
  .day__schedule__list > dt {
    width: 8rem;
    padding-right: 0;
  }
}
.day__schedule__list > dt::after {
  position: absolute;
  top: 0;
  right: 2rem;
  content: "：";
}
@media all and (max-width: 900px) {
  .day__schedule__list > dt::after {
    right: 1rem;
  }
}
.day__schedule__list > dd {
  width: calc(100% - 14rem);
}
@media all and (max-width: 900px) {
  .day__schedule__list > dd {
    width: calc(100% - 8rem);
  }
}
.day__activity {
  display: flex;
  align-items: center;
  flex-wrap: wrap;
  gap: 6.2rem 6.6rem;
}
@media all and (max-width: 900px) {
  .day__activity {
    flex-direction: column;
    gap: 3.2rem;
  }
}
.day__activity__col {
  position: relative;
  z-index: 2;
  order: 2;
  width: 66.5rem;
}
@media all and (max-width: 900px) {
  .day__activity__col {
    order: 1;
    width: auto;
  }
}
.day__activity__col2 {
  position: relative;
  order: 1;
  width: 66.5rem;
}
@media all and (max-width: 900px) {
  .day__activity__col2 {
    order: 2;
    width: auto;
  }
}
.day__activity__col2::before {
  content: "";
  position: absolute;
  z-index: 1;
  top: -8.7rem;
  left: -12rem;
  width: 24.9rem;
  aspect-ratio: 249/211;
  background: url(../images/day_bg_001.png) no-repeat 0 0;
  background-size: 100% 100%;
}
@media all and (max-width: 900px) {
  .day__activity__col2::before {
    top: -2.4rem;
    left: -2.4rem;
    width: 10.7rem;
  }
}
.day__activity__col3 {
  position: relative;
  order: 3;
  width: 66.5rem;
}
@media all and (max-width: 900px) {
  .day__activity__col3 {
    width: auto;
  }
}
.day__activity__col3::before {
  content: "";
  position: absolute;
  z-index: 1;
  bottom: -13.5rem;
  left: -13.5rem;
  width: 70.1rem;
  aspect-ratio: 701/455;
  background: url(../images/day_bg_002.png) no-repeat 0 0;
  background-size: 100% 100%;
}
@media all and (max-width: 900px) {
  .day__activity__col3::before {
    bottom: -4.2rem;
    left: -7.3rem;
    width: 30rem;
  }
}
.day__activity__col4 {
  position: relative;
  order: 4;
  width: 66.5rem;
}
@media all and (max-width: 900px) {
  .day__activity__col4 {
    width: auto;
  }
}
.day__activity__col4::before {
  content: "";
  position: absolute;
  z-index: 1;
  bottom: -10.6rem;
  right: -12rem;
  width: 24.9rem;
  aspect-ratio: 249/211;
  background: url(../images/day_bg_001.png) no-repeat 0 0;
  background-size: 100% 100%;
}
@media all and (max-width: 900px) and (max-width: 900px) {
  .day__activity__col4::before {
    bottom: -2.4rem;
    right: -2.4rem;
    width: 10.7rem;
  }
}
.day__activity__ttl {
  margin-bottom: 2.4rem;
  font-size: 3.6rem;
  font-weight: 700;
  color: #4aa9a1;
}
@media all and (max-width: 900px) {
  .day__activity__ttl {
    font-size: 1.8rem;
    text-align: center;
  }
}
.day__activity__txt {
  margin-bottom: 0;
  font-size: 1.8rem;
  color: #132c42;
}
@media all and (max-width: 900px) {
  .day__activity__txt {
    font-size: 1.1rem;
  }
}
.day__activity__img {
  position: relative;
  z-index: 2;
  border-radius: 1.4rem;
  overflow: hidden;
  width: 66.5rem;
  aspect-ratio: 665/425;
}
@media all and (max-width: 900px) {
  .day__activity__img {
    width: auto;
    border-radius: 0.7rem;
  }
}
.day__activity img {
  width: 100%;
  height: 100%;
  -o-object-fit: cover;
     object-fit: cover;
}

.sns {
  margin: 8.8rem 0 0;
}
@media all and (max-width: 900px) {
  .sns {
    margin-top: 4.8rem;
  }
}
.sns__list {
  display: flex;
  align-items: center;
  justify-content: center;
  gap: 4.6rem;
  margin: 0;
  list-style-type: none;
}
@media all and (max-width: 900px) {
  .sns__list {
    gap: 1.6rem;
  }
}
.sns__list__item a {
  display: block;
  width: 7.1rem;
  height: 7.1rem;
  text-indent: -999rem;
  overflow: hidden;
  background: no-repeat 0 0;
  background-size: 100% 100%;
}
@media all and (max-width: 900px) {
  .sns__list__item a {
    width: 4rem;
    height: 4rem;
  }
}
.sns__list__item--facebook a {
  background-image: url(../images/ic_facebook_001.png);
}
.sns__list__item--x a {
  background-image: url(../images/ic_x_001.png);
}
.sns__list__item--line a {
  background-image: url(../images/ic_line_002.png);
}
.article {
  overflow: hidden;
  font-size: 1.8rem;
}
@media all and (max-width: 900px) {
  .article {
    font-size: 1.2rem;
  }
}
.article img {
  border-radius: 1.4rem;
}
@media all and (max-width: 900px) {
  .article img {
    border-radius: 0.7rem;
  }
}
.article h2 {
  position: relative;
  font-size: 3.2rem;
  font-weight: 700;
  text-align: center;
  color: #45ada4;
  margin-bottom: 6rem;
  padding-bottom: 2.4rem;
}
@media all and (max-width: 900px) {
  .article h2 {
    font-size: 1.8rem;
    margin-bottom: 4rem;
    padding-bottom: 1.6rem;
  }
}
.article h2::before {
  content: "";
  position: absolute;
  bottom: 0;
  left: 50%;
  transform: translateX(-50%);
  width: 9.6rem;
  height: 0.2rem;
  background-color: #45ada4;
}
@media all and (max-width: 900px) {
  .article h2::before {
    width: 6.4rem;
  }
}
.article h3 {
  position: relative;
  margin: 3.6rem 0;
  padding: 2rem 4rem;
  background-color: #edf9f7;
  border-radius: 1rem;
  overflow: hidden;
  color: #4aa9a1;
  font-size: 2.4rem;
  font-weight: 700;
}
@media all and (max-width: 900px) {
  .article h3 {
    margin: 2rem 0;
    padding: 1.2rem;
    border-radius: 0.5rem;
    font-size: 1.4rem;
  }
}
.article h3::before {
  content: "";
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  height: 0.3rem;
  background-color: #45ada4;
}
.article h4 {
  position: relative;
  margin: 3.6rem 0;
  padding: 0.8rem 2rem 2rem;
  color: #4aa9a1;
  font-size: 2.4rem;
  font-weight: 700;
  border-bottom: 0.4rem solid #d2efec;
}
@media all and (max-width: 900px) {
  .article h4 {
    margin: 2rem 0;
    padding: 0.4rem 1.2rem 1.4rem;
    font-size: 1.4rem;
  }
}
.article h4::before {
  content: "";
  position: absolute;
  top: 0;
  bottom: 1rem;
  left: 0;
  width: 0.4rem;
  border-radius: 0.2rem;
  background-color: #4aa9a1;
}
@media all and (max-width: 900px) {
  .article h4::before {
    bottom: 0.8rem;
    width: 0.3rem;
  }
}
.article h5 {
  margin: 3rem 0;
  padding-bottom: 1.6rem;
  color: #4aa9a1;
  font-size: 2.2rem;
  font-weight: 700;
  border-bottom: 0.2rem solid #4aa9a1;
}
@media all and (max-width: 900px) {
  .article h5 {
    margin: 1.8rem 0;
    padding-bottom: 0.8rem;
    font-size: 1.3rem;
  }
}
.article h6 {
  margin: 3rem 0;
  padding: 1.2rem 2rem;
  background-color: #edf9f7;
  border-radius: 1rem;
  color: #4aa9a1;
  font-size: 2rem;
  font-weight: 700;
}

@media all and (max-width: 900px) {
  .article h6 {
    margin: 1.8rem 0;
    padding: 0.8rem 1.2rem;
    border-radius: 0.5rem;
    font-size: 1.3rem;
  }
}

.article p {
  margin: 0 0 1em;
  padding: 0;
}


.article ul {
  margin-bottom: 4rem;
  list-style-type: none;
}
@media all and (max-width: 900px) {
  .article ul {
    margin-bottom: 2.4rem;
  }
}
.article ul > li {
  position: relative;
  padding-left: 1.4rem;
  margin-left: 1.4rem;
}
.article ul > li:before {
  content: "";
  position: absolute;
  top: 0.65em;
  left: 0;
  width: 0.6rem;
  height: 0.6rem;
  border-radius: 50%;
  background: #45ada4;
}
@media all and (max-width: 900px) {
  .article ul > li:before {
    width: 0.5rem;
    height: 0.5rem;
  }
}
.article ol {
  margin-bottom: 4rem;
}
@media all and (max-width: 900px) {
  .article ol {
    margin-bottom: 2.4rem;
  }
}
.article ol > li {
  list-style-type: decimal;
  margin-left: 2.5em;
}
.article blockquote {
  background-color: #fff;
  border-left: 0.4rem solid #45ada4;
  padding: 2.4rem 4rem;
  margin: 6rem 0;
}
@media all and (max-width: 900px) {
  .article blockquote {
    border-width: 0.3rem;
    padding: 1.2rem;
    margin: 2.4rem 0;
  }
}
.article blockquote p, .article blockquote ul, .article blockquote ol, .article blockquote dl {
  margin-bottom: 0;
  margin-bottom: 0;
}
.article hr {
  clear: both;
  border: none;
  border-top: 0.2rem solid #45ada4;
  margin: 6rem 0;
}
@media all and (max-width: 900px) {
  .article hr {
    border-top-width: 0.2rem;
    margin: 2.4rem 0;
  }
}
.article pre {
  background-color: #edf9f7;
  padding: 2.4rem 4rem;
  margin: 6rem 0;
  border-radius: 1.4rem;
  white-space: pre-wrap;
}
@media all and (max-width: 900px) {
  .article pre {
    padding: 1.2rem;
    margin: 2.4rem 0;
    border-radius: 0.7rem;
  }
}
.article .alignleft {
  clear: both;
  float: left;
  margin-right: 4rem;
  margin-bottom: 6rem;
}
@media all and (max-width: 900px) {
  .article .alignleft {
    float: none;
    display: block;
    margin-right: auto;
    margin-left: auto;
    max-width: 100%;
    height: auto;
    margin-bottom: 2.4rem;
  }
}
.article .aligncenter {
  display: table;
  clear: both;
  margin-left: auto;
  margin-right: auto;
/*  margin-bottom: 6rem; */
  margin-bottom: 0;
  width: 72rem;
  height: auto;
}
@media all and (max-width: 900px) {
  .article .aligncenter {
    float: none;
    display: block;
    margin-right: auto;
    margin-left: auto;
    max-width: 100%;
/*  margin-bottom: 2.4rem; */
    margin-bottom: 0;

  }
}
.article .alignright {
  clear: both;
  float: right;
  margin-left: 4rem;
  margin-bottom: 6em;
}
@media all and (max-width: 900px) {
  .article .alignright {
    float: none;
    display: block;
    margin-right: auto;
    margin-left: auto;
    max-width: 100%;
    height: auto;
    margin-bottom: 2.4rem;
  }
}
.article > :first-child {
  margin-top: 0;
}
.article > :last-child {
  margin-bottom: 0;
}